pub struct Config {
pub workdir_path: Option<PathBuf>,
pub config_path: Option<PathBuf>,
pub timeout_ms: u64,
pub load_workspace_modules: bool,
pub execute_timeout_ms: Option<u64>,
pub logger: Option<DynLogger>,
}Fields
workdir_path: Option<PathBuf>The host workdir loaded into dagger.
config_path: Option<PathBuf>Project configuration file path.
timeout_ms: u64The maximum time in milliseconds for establishing a connection to the server. Defaults to 10 seconds.
load_workspace_modules: boolOpt into loading workspace modules for this connection.
execute_timeout_ms: Option<u64>The maximum time in milliseconds for executing a request. Defaults to no timeout.
logger: Option<DynLogger>Logger implementation to handle logs from the engine.
Implementations