pub struct ConfigBuilder { /* private fields */ }Expand description
Builder for Config.
Implementations
Sourceimpl ConfigBuilder
impl ConfigBuilder
Sourcepub fn workdir_path(&mut self, value: PathBuf) -> &mut Self
pub fn workdir_path(&mut self, value: PathBuf) -> &mut Self
The host workdir loaded into dagger.
Sourcepub fn config_path(&mut self, value: PathBuf) -> &mut Self
pub fn config_path(&mut self, value: PathBuf) -> &mut Self
Project configuration file path.
Sourcepub fn timeout_ms(&mut self, value: u64) -> &mut Self
pub fn timeout_ms(&mut self, value: u64) -> &mut Self
The maximum time in milliseconds for establishing a connection to the server. Defaults to 10 seconds.
Sourcepub fn load_workspace_modules(&mut self, value: bool) -> &mut Self
pub fn load_workspace_modules(&mut self, value: bool) -> &mut Self
Opt into loading workspace modules for this connection.
Sourcepub fn execute_timeout_ms(&mut self, value: u64) -> &mut Self
pub fn execute_timeout_ms(&mut self, value: u64) -> &mut Self
The maximum time in milliseconds for executing a request. Defaults to no timeout.