pub struct AgentGroup {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl AgentGroup
impl AgentGroup
Sourcepub fn compose(&self) -> Llm
pub fn compose(&self) -> Llm
Compose all selected agent middlewares onto a base LLM, in alphabetical module:fn order, and return the composed LLM.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn compose_opts(&self, opts: AgentGroupComposeOpts) -> Llm
pub fn compose_opts(&self, opts: AgentGroupComposeOpts) -> Llm
Compose all selected agent middlewares onto a base LLM, in alphabetical module:fn order, and return the composed LLM.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this AgentGroup.