pub struct AgentMiddlewareGroup {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl AgentMiddlewareGroup
impl AgentMiddlewareGroup
Sourcepub fn compose(&self) -> Llm
pub fn compose(&self) -> Llm
Compose all selected agent middlewares onto a base LLM, in alphabetical module:fn order, and return the composed LLM.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn compose_opts(&self, opts: AgentMiddlewareGroupComposeOpts) -> Llm
pub fn compose_opts(&self, opts: AgentMiddlewareGroupComposeOpts) -> Llm
Compose all selected agent middlewares onto a base LLM, in alphabetical module:fn order, and return the composed LLM.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this AgentMiddlewareGroup.
Sourcepub async fn list(&self) -> Result<Vec<AgentMiddleware>, DaggerError>
pub async fn list(&self) -> Result<Vec<AgentMiddleware>, DaggerError>
Return a list of individual agents and their details