pub struct AgentSendOptsBuilder<'a> { /* private fields */ }Expand description
Builder for AgentSendOpts.
Implementations
Sourceimpl<'a> AgentSendOptsBuilder<'a>
impl<'a> AgentSendOptsBuilder<'a>
Sourcepub fn reply_to<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn reply_to<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
The ref of a message in the SENDER’s own mailbox this send answers (e.g. “#3”, from its attribution header). The recipient sees the two paired, and awaiters of the replied-to message resolve with this reply immediately instead of at the sender’s turn end.
Sourcepub fn build(&self) -> Result<AgentSendOpts<'a>, AgentSendOptsBuilderError>
pub fn build(&self) -> Result<AgentSendOpts<'a>, AgentSendOptsBuilderError>