pub struct AgentStopOptsBuilder { /* private fields */ }Expand description
Builder for AgentStopOpts.
Implementations
Sourceimpl AgentStopOptsBuilder
impl AgentStopOptsBuilder
Sourcepub fn kill<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn kill<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Cancel the loop immediately instead of letting an in-flight step finish. Either way the completed steps are preserved in the snapshot.
Sourcepub fn build(&self) -> Result<AgentStopOpts, AgentStopOptsBuilderError>
pub fn build(&self) -> Result<AgentStopOpts, AgentStopOptsBuilderError>