pub struct ContainerAsServiceOpts<'a> {
pub args: Option<Vec<&'a str>>,
pub expand: Option<bool>,
pub experimental_privileged_nesting: Option<bool>,
pub insecure_root_capabilities: Option<bool>,
pub no_init: Option<bool>,
pub use_entrypoint: Option<bool>,
}Fields
args: Option<Vec<&'a str>>Command to run instead of the container’s default command (e.g., [“go”, “run”, “main.go”]). If empty, the container’s default command is used.
expand: Option<bool>Replace “${VAR}” or “$VAR” in the args according to the current environment variables defined in the container (e.g. “/$VAR/foo”).
experimental_privileged_nesting: Option<bool>Provides Dagger access to the executed command.
insecure_root_capabilities: Option<bool>Execute the command with all root capabilities. This is similar to running a command with “sudo” or executing “docker run” with the “–privileged” flag. Containerization does not provide any security guarantees when using this option. It should only be used when absolutely necessary and only with trusted commands.
no_init: Option<bool>If set, skip the automatic init process injected into containers by default. This should only be used if the user requires that their exec process be the pid 1 process in the container. Otherwise it may result in unexpected behavior.
use_entrypoint: Option<bool>If the container has an entrypoint, prepend it to the args.