pub struct ContainerAsTarballOpts {
pub forced_compression: Option<ImageLayerCompression>,
pub media_types: Option<ImageMediaTypes>,
pub platform_variants: Option<Vec<ContainerId>>,
}Fields
forced_compression: Option<ImageLayerCompression>Force each layer of the image to use the specified compression algorithm. If this is unset, then if a layer already has a compressed blob in the engine’s cache, that will be used (this can result in a mix of compression algorithms for different layers). If this is unset and a layer has no compressed blob in the engine’s cache, then it will be compressed using Gzip.
media_types: Option<ImageMediaTypes>Use the specified media types for the image’s layers. Defaults to OCI, which is largely compatible with most recent container runtimes, but Docker may be needed for older runtimes without OCI support.
platform_variants: Option<Vec<ContainerId>>Identifiers for other platform specific containers. Used for multi-platform images.