Struct dagger_sdk::ContainerExecOpts
source · pub struct ContainerExecOpts<'a> {
pub args: Option<Vec<&'a str>>,
pub experimental_privileged_nesting: Option<bool>,
pub redirect_stderr: Option<&'a str>,
pub redirect_stdout: Option<&'a str>,
pub stdin: Option<&'a str>,
}Fields
args: Option<Vec<&'a str>>Command to run instead of the container’s default command (e.g., [“run”, “main.go”]).
experimental_privileged_nesting: Option<bool>Provide dagger access to the executed command. Do not use this option unless you trust the command being executed. The command being executed WILL BE GRANTED FULL ACCESS TO YOUR HOST FILESYSTEM.
redirect_stderr: Option<&'a str>Redirect the command’s standard error to a file in the container (e.g., “/tmp/stderr”).
redirect_stdout: Option<&'a str>Redirect the command’s standard output to a file in the container (e.g., “/tmp/stdout”).
stdin: Option<&'a str>Content to write to the command’s standard input before closing (e.g., “Hello world”).