pub struct ContainerExecOptsBuilder<'a> { /* private fields */ }
Builder for ContainerExecOpts.

Implementations

source

impl<'a> ContainerExecOptsBuilder<'a>

source

pub fn args<VALUE: Into<Vec<&'a str>>>(&mut self, value: VALUE) -> &mut Self

Command to run instead of the container’s default command.

source

pub fn stdin<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self

Content to write to the command’s standard input before closing.

source

pub fn redirect_stdout<VALUE: Into<&'a str>>( &mut self, value: VALUE ) -> &mut Self

Redirect the command’s standard output to a file in the container.

source

pub fn redirect_stderr<VALUE: Into<&'a str>>( &mut self, value: VALUE ) -> &mut Self

Redirect the command’s standard error to a file in the container.

source

pub fn experimental_privileged_nesting<VALUE: Into<bool>>( &mut self, value: VALUE ) -> &mut Self

Provide dagger access to the executed command. Do not use this option unless you trust the command being executed. The command being executed WILL BE GRANTED FULL ACCESS TO YOUR HOST FILESYSTEM.

source

pub fn build( &self ) -> Result<ContainerExecOpts<'a>, ContainerExecOptsBuilderError>

Builds a new ContainerExecOpts.

Errors

If a required field has not been initialized.