pub struct ContainerExportOptsBuilder { /* private fields */ }Expand description
Builder for ContainerExportOpts.
Implementations
Sourceimpl ContainerExportOptsBuilder
impl ContainerExportOptsBuilder
Sourcepub fn expand<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn expand<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Replace “${VAR}” or “$VAR” in the value of path according to the current environment variables defined in the container (e.g. “/$VAR/foo”).
Sourcepub fn forced_compression<VALUE: Into<ImageLayerCompression>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn forced_compression<VALUE: Into<ImageLayerCompression>>( &mut self, value: VALUE, ) -> &mut Self
Force each layer of the exported image to use the specified compression algorithm. If this is unset, then if a layer already has a compressed blob in the engine’s cache, that will be used (this can result in a mix of compression algorithms for different layers). If this is unset and a layer has no compressed blob in the engine’s cache, then it will be compressed using Gzip.
Sourcepub fn media_types<VALUE: Into<ImageMediaTypes>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn media_types<VALUE: Into<ImageMediaTypes>>( &mut self, value: VALUE, ) -> &mut Self
Use the specified media types for the exported image’s layers. Defaults to OCI, which is largely compatible with most recent container runtimes, but Docker may be needed for older runtimes without OCI support.
Sourcepub fn platform_variants<VALUE: Into<Vec<Id>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn platform_variants<VALUE: Into<Vec<Id>>>( &mut self, value: VALUE, ) -> &mut Self
Identifiers for other platform specific containers. Used for multi-platform image.
Sourcepub fn build(
&self,
) -> Result<ContainerExportOpts, ContainerExportOptsBuilderError>
pub fn build( &self, ) -> Result<ContainerExportOpts, ContainerExportOptsBuilderError>