pub struct ContainerFromOpts<'a> {
pub insecure_skip_tls_verify: Option<bool>,
pub protocol: Option<RegistryProtocol>,
pub registry_service: Option<Id>,
pub version: Option<&'a str>,
}Fields
insecure_skip_tls_verify: Option<bool>Allow HTTPS registry communication without verifying the server certificate.
protocol: Option<RegistryProtocol>Protocol to use for registry communication. Defaults to “HTTPS”. Use “HTTP” only for plain HTTP registries.
registry_service: Option<Id>Service to use as the registry endpoint for the image address. The service will be started only for this pull.
version: Option<&'a str>Version query used to select an image tag. The address must not contain a tag or digest.