pub struct ContainerFromOptsBuilder { /* private fields */ }Expand description
Builder for ContainerFromOpts.
Implementations
Sourceimpl ContainerFromOptsBuilder
impl ContainerFromOptsBuilder
Sourcepub fn registry_service<VALUE: Into<Id>>(&mut self, value: VALUE) -> &mut Self
pub fn registry_service<VALUE: Into<Id>>(&mut self, value: VALUE) -> &mut Self
Service to use as the registry endpoint for the image address. The service will be started only for this pull.
Sourcepub fn build(&self) -> Result<ContainerFromOpts, ContainerFromOptsBuilderError>
pub fn build(&self) -> Result<ContainerFromOpts, ContainerFromOptsBuilderError>