pub struct ContainerLayerOpts {
pub forced_compression: Option<ImageLayerCompression>,
pub media_types: Option<ImageMediaTypes>,
}Fields
forced_compression: Option<ImageLayerCompression>Force each layer of the image to use the specified compression algorithm. If this is unset, then if a layer already has a compressed blob in the engine’s cache, that will be used (this can result in a mix of compression algorithms for different layers). If this is unset and a layer has no compressed blob in the engine’s cache, then it will be compressed using Gzip.
media_types: Option<ImageMediaTypes>Media types to use for image layers. Defaults to OCI.