pub struct ContainerManifestOptsBuilder { /* private fields */ }Expand description
Builder for ContainerManifestOpts.
Implementations
Sourceimpl ContainerManifestOptsBuilder
impl ContainerManifestOptsBuilder
Sourcepub fn forced_compression<VALUE: Into<ImageLayerCompression>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn forced_compression<VALUE: Into<ImageLayerCompression>>( &mut self, value: VALUE, ) -> &mut Self
Force each layer of the image to use the specified compression algorithm. If this is unset, then if a layer already has a compressed blob in the engine’s cache, that will be used (this can result in a mix of compression algorithms for different layers). If this is unset and a layer has no compressed blob in the engine’s cache, then it will be compressed using Gzip.
Sourcepub fn media_types<VALUE: Into<ImageMediaTypes>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn media_types<VALUE: Into<ImageMediaTypes>>( &mut self, value: VALUE, ) -> &mut Self
Media types to use for image layers. Defaults to OCI.
Sourcepub fn build(
&self,
) -> Result<ContainerManifestOpts, ContainerManifestOptsBuilderError>
pub fn build( &self, ) -> Result<ContainerManifestOpts, ContainerManifestOptsBuilderError>