ContainerWithDockerHealthcheckOpts

Struct ContainerWithDockerHealthcheckOpts 

pub struct ContainerWithDockerHealthcheckOpts<'a> {
    pub interval: Option<&'a str>,
    pub retries: Option<isize>,
    pub shell: Option<bool>,
    pub start_interval: Option<&'a str>,
    pub start_period: Option<&'a str>,
    pub timeout: Option<&'a str>,
}

Fields

interval: Option<&'a str>

Interval between running healthcheck. Example: “30s”

retries: Option<isize>

The maximum number of consecutive failures before the container is marked as unhealthy. Example: “3”

shell: Option<bool>

When true, command must be a single element, which is run using the container’s shell

start_interval: Option<&'a str>

StartInterval configures the duration between checks during the startup phase. Example: “5s”

start_period: Option<&'a str>

StartPeriod allows for failures during this initial startup period which do not count towards maximum number of retries. Example: “0s”

timeout: Option<&'a str>

Healthcheck timeout. Example: “3s”