pub struct ContainerWithDockerHealthcheckOptsBuilder<'a> { /* private fields */ }Expand description
Builder for ContainerWithDockerHealthcheckOpts.
Implementations
Sourceimpl<'a> ContainerWithDockerHealthcheckOptsBuilder<'a>
impl<'a> ContainerWithDockerHealthcheckOptsBuilder<'a>
Sourcepub fn interval<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn interval<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
Interval between running healthcheck. Example: “30s”
Sourcepub fn retries<VALUE: Into<isize>>(&mut self, value: VALUE) -> &mut Self
pub fn retries<VALUE: Into<isize>>(&mut self, value: VALUE) -> &mut Self
The maximum number of consecutive failures before the container is marked as unhealthy. Example: “3”
Sourcepub fn shell<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn shell<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
When true, command must be a single element, which is run using the container’s shell
Sourcepub fn start_interval<VALUE: Into<&'a str>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn start_interval<VALUE: Into<&'a str>>( &mut self, value: VALUE, ) -> &mut Self
StartInterval configures the duration between checks during the startup phase. Example: “5s”
Sourcepub fn start_period<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn start_period<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
StartPeriod allows for failures during this initial startup period which do not count towards maximum number of retries. Example: “0s”
Sourcepub fn timeout<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn timeout<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
Healthcheck timeout. Example: “3s”
Sourcepub fn build(
&self,
) -> Result<ContainerWithDockerHealthcheckOpts<'a>, ContainerWithDockerHealthcheckOptsBuilderError>
pub fn build( &self, ) -> Result<ContainerWithDockerHealthcheckOpts<'a>, ContainerWithDockerHealthcheckOptsBuilderError>
Builds a new ContainerWithDockerHealthcheckOpts.
Errors
If a required field has not been initialized.