pub struct ContainerWithEntrypointOpts {
pub keep_default_args: Option<bool>,
}Fields
keep_default_args: Option<bool>Don’t reset the default arguments when setting the entrypoint. By default it is reset, since entrypoint and default args are often tightly coupled.