pub struct ContainerWithEntrypointOptsBuilder { /* private fields */ }Expand description
Builder for ContainerWithEntrypointOpts.
Implementations
Sourceimpl ContainerWithEntrypointOptsBuilder
impl ContainerWithEntrypointOptsBuilder
Sourcepub fn keep_default_args<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn keep_default_args<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Don’t reset the default arguments when setting the entrypoint. By default it is reset, since entrypoint and default args are often tightly coupled.
Sourcepub fn build(
&self,
) -> Result<ContainerWithEntrypointOpts, ContainerWithEntrypointOptsBuilderError>
pub fn build( &self, ) -> Result<ContainerWithEntrypointOpts, ContainerWithEntrypointOptsBuilderError>