Struct dagger_sdk::ContainerWithExecOpts
source · pub struct ContainerWithExecOpts<'a> {
pub stdin: Option<&'a str>,
pub redirect_stdout: Option<&'a str>,
pub redirect_stderr: Option<&'a str>,
pub experimental_privileged_nesting: Option<bool>,
}Fields
stdin: Option<&'a str>Content to write to the command’s standard input before closing.
redirect_stdout: Option<&'a str>Redirect the command’s standard output to a file in the container.
redirect_stderr: Option<&'a str>Redirect the command’s standard error to a file in the container.
experimental_privileged_nesting: Option<bool>Provide dagger access to the executed command. Do not use this option unless you trust the command being executed. The command being executed WILL BE GRANTED FULL ACCESS TO YOUR HOST FILESYSTEM.