pub struct ContainerWithExecOptsBuilder<'a> { /* private fields */ }Expand description
Builder for ContainerWithExecOpts.
Implementations
Sourceimpl<'a> ContainerWithExecOptsBuilder<'a>
impl<'a> ContainerWithExecOptsBuilder<'a>
Sourcepub fn expand<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn expand<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Replace “${VAR}” or “$VAR” in the args according to the current environment variables defined in the container (e.g. “/$VAR/foo”).
Sourcepub fn expect<VALUE: Into<ReturnType>>(&mut self, value: VALUE) -> &mut Self
pub fn expect<VALUE: Into<ReturnType>>(&mut self, value: VALUE) -> &mut Self
Exit codes this command is allowed to exit with without error
Sourcepub fn experimental_privileged_nesting<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn experimental_privileged_nesting<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Provides Dagger access to the executed command. Do not use this option unless you trust the command being executed; the command being executed WILL BE GRANTED FULL ACCESS TO YOUR HOST FILESYSTEM.
Sourcepub fn insecure_root_capabilities<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn insecure_root_capabilities<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Execute the command with all root capabilities. This is similar to running a command with “sudo” or executing “docker run” with the “–privileged” flag. Containerization does not provide any security guarantees when using this option. It should only be used when absolutely necessary and only with trusted commands.
Sourcepub fn no_init<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn no_init<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If set, skip the automatic init process injected into containers by default. This should only be used if the user requires that their exec process be the pid 1 process in the container. Otherwise it may result in unexpected behavior.
Sourcepub fn redirect_stderr<VALUE: Into<&'a str>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn redirect_stderr<VALUE: Into<&'a str>>( &mut self, value: VALUE, ) -> &mut Self
Redirect the command’s standard error to a file in the container (e.g., “/tmp/stderr”).
Sourcepub fn redirect_stdout<VALUE: Into<&'a str>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn redirect_stdout<VALUE: Into<&'a str>>( &mut self, value: VALUE, ) -> &mut Self
Redirect the command’s standard output to a file in the container (e.g., “/tmp/stdout”).
Sourcepub fn stdin<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn stdin<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
Content to write to the command’s standard input before closing (e.g., “Hello world”).
Sourcepub fn use_entrypoint<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn use_entrypoint<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If the container has an entrypoint, prepend it to the args.
Sourcepub fn build(
&self,
) -> Result<ContainerWithExecOpts<'a>, ContainerWithExecOptsBuilderError>
pub fn build( &self, ) -> Result<ContainerWithExecOpts<'a>, ContainerWithExecOptsBuilderError>