Struct dagger_sdk::ContainerWithFilesOpts
source · pub struct ContainerWithFilesOpts<'a> {
pub owner: Option<&'a str>,
pub permissions: Option<isize>,
}Fields
owner: Option<&'a str>A user:group to set for the files. The user and group can either be an ID (1000:1000) or a name (foo:bar). If the group is omitted, it defaults to the same as the user.
permissions: Option<isize>Permission given to the copied files (e.g., 0600).