pub struct ContainerWithMountedDirectoryOpts<'a> {
pub expand: Option<bool>,
pub inherit_owner: Option<bool>,
pub owner: Option<&'a str>,
pub read_only: Option<bool>,
}Fields
expand: Option<bool>Replace “${VAR}” or “$VAR” in the value of path according to the current environment variables defined in the container (e.g. “/$VAR/foo”).
inherit_owner: Option<bool>Set the owner to the container’s current user.
owner: Option<&'a str>A user:group to set for the mounted directory and its contents. The user and group can either be an ID (1000:1000) or a name (foo:bar). If the group is omitted, it defaults to the same as the user.
read_only: Option<bool>Mount the directory read-only.