pub struct ContainerWithMountedSecretOpts<'a> {
pub expand: Option<bool>,
pub inherit_owner: Option<bool>,
pub mode: Option<isize>,
pub owner: Option<&'a str>,
}Fields
expand: Option<bool>Replace “${VAR}” or “$VAR” in the value of path according to the current environment variables defined in the container (e.g. “/$VAR/foo”).
inherit_owner: Option<bool>Set the owner to the container’s current user.
mode: Option<isize>Permission given to the mounted secret (e.g., 0600). This option requires an owner to be set to be active.
owner: Option<&'a str>A user:group to set for the mounted secret. The user and group can either be an ID (1000:1000) or a name (foo:bar). If the group is omitted, it defaults to the same as the user.