pub struct ContainerWithMountedSecretOptsBuilder<'a> { /* private fields */ }Expand description
Builder for ContainerWithMountedSecretOpts.
Implementations
sourceimpl<'a> ContainerWithMountedSecretOptsBuilder<'a>
impl<'a> ContainerWithMountedSecretOptsBuilder<'a>
sourcepub fn mode<VALUE: Into<isize>>(&mut self, value: VALUE) -> &mut Self
pub fn mode<VALUE: Into<isize>>(&mut self, value: VALUE) -> &mut Self
Permission given to the mounted secret (e.g., 0600). This option requires an owner to be set to be active.
sourcepub fn owner<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn owner<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
A user:group to set for the mounted secret. The user and group can either be an ID (1000:1000) or a name (foo:bar). If the group is omitted, it defaults to the same as the user.
sourcepub fn build(
&self,
) -> Result<ContainerWithMountedSecretOpts<'a>, ContainerWithMountedSecretOptsBuilderError>
pub fn build( &self, ) -> Result<ContainerWithMountedSecretOpts<'a>, ContainerWithMountedSecretOptsBuilderError>