pub struct ContainerWithUnixSocketOptsBuilder<'a> { /* private fields */ }Expand description
Builder for ContainerWithUnixSocketOpts.
Implementations
Sourceimpl<'a> ContainerWithUnixSocketOptsBuilder<'a>
impl<'a> ContainerWithUnixSocketOptsBuilder<'a>
Sourcepub fn expand<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn expand<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Replace “${VAR}” or “$VAR” in the value of path according to the current environment variables defined in the container (e.g. “/$VAR/foo”).
Sourcepub fn inherit_owner<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn inherit_owner<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Set the owner to the container’s current user.
Sourcepub fn owner<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn owner<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
A user:group to set for the mounted socket. The user and group can either be an ID (1000:1000) or a name (foo:bar). If the group is omitted, it defaults to the same as the user.
Sourcepub fn build(
&self,
) -> Result<ContainerWithUnixSocketOpts<'a>, ContainerWithUnixSocketOptsBuilderError>
pub fn build( &self, ) -> Result<ContainerWithUnixSocketOpts<'a>, ContainerWithUnixSocketOptsBuilderError>