pub struct CurrentModule {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl CurrentModule
impl CurrentModule
Sourcepub async fn dependencies(&self) -> Result<Vec<Module>, DaggerError>
pub async fn dependencies(&self) -> Result<Vec<Module>, DaggerError>
The dependencies of the module.
Sourcepub fn generated_context_directory(&self) -> Directory
pub fn generated_context_directory(&self) -> Directory
The generated files and directories made on top of the module source’s context directory.
Sourcepub fn generators(&self) -> GeneratorGroup
pub fn generators(&self) -> GeneratorGroup
Return all generators defined by the module
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn generators_opts<'a>(
&self,
opts: CurrentModuleGeneratorsOpts<'a>,
) -> GeneratorGroup
pub fn generators_opts<'a>( &self, opts: CurrentModuleGeneratorsOpts<'a>, ) -> GeneratorGroup
Return all generators defined by the module
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this CurrentModule.
Sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
The name of the module being executed in
Sourcepub fn source(&self) -> Directory
pub fn source(&self) -> Directory
The directory containing the module’s source code loaded into the engine (plus any generated code that may have been created).
Sourcepub fn workdir(&self, path: impl Into<String>) -> Directory
pub fn workdir(&self, path: impl Into<String>) -> Directory
Load a directory from the module’s scratch working directory, including any changes that may have been made to it during module function execution.
Arguments
path- Location of the directory to access (e.g., “.”).opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn workdir_opts<'a>(
&self,
path: impl Into<String>,
opts: CurrentModuleWorkdirOpts<'a>,
) -> Directory
pub fn workdir_opts<'a>( &self, path: impl Into<String>, opts: CurrentModuleWorkdirOpts<'a>, ) -> Directory
Load a directory from the module’s scratch working directory, including any changes that may have been made to it during module function execution.
Arguments
path- Location of the directory to access (e.g., “.”).opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn workdir_file(&self, path: impl Into<String>) -> File
pub fn workdir_file(&self, path: impl Into<String>) -> File
Load a file from the module’s scratch working directory, including any changes that may have been made to it during module function execution.Load a file from the module’s scratch working directory, including any changes that may have been made to it during module function execution.
Arguments
path- Location of the file to retrieve (e.g., “README.md”).