Struct dagger_sdk::DaggerEngineCache
source · pub struct DaggerEngineCache {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
sourceimpl DaggerEngineCache
impl DaggerEngineCache
sourcepub fn entry_set(&self) -> DaggerEngineCacheEntrySet
pub fn entry_set(&self) -> DaggerEngineCacheEntrySet
The current set of entries in the cache
sourcepub async fn id(&self) -> Result<DaggerEngineCacheId, DaggerError>
pub async fn id(&self) -> Result<DaggerEngineCacheId, DaggerError>
A unique identifier for this DaggerEngineCache.
sourcepub async fn keep_bytes(&self) -> Result<isize, DaggerError>
pub async fn keep_bytes(&self) -> Result<isize, DaggerError>
The maximum bytes to keep in the cache without pruning, after which automatic pruning may kick in.
sourcepub async fn prune(&self) -> Result<Void, DaggerError>
pub async fn prune(&self) -> Result<Void, DaggerError>
Prune the cache of releaseable entries