Struct dagger_sdk::DaggerEngineCacheEntry
source · pub struct DaggerEngineCacheEntry {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
sourceimpl DaggerEngineCacheEntry
impl DaggerEngineCacheEntry
sourcepub async fn actively_used(&self) -> Result<bool, DaggerError>
pub async fn actively_used(&self) -> Result<bool, DaggerError>
Whether the cache entry is actively being used.
sourcepub async fn created_time_unix_nano(&self) -> Result<isize, DaggerError>
pub async fn created_time_unix_nano(&self) -> Result<isize, DaggerError>
The time the cache entry was created, in Unix nanoseconds.
sourcepub async fn description(&self) -> Result<String, DaggerError>
pub async fn description(&self) -> Result<String, DaggerError>
The description of the cache entry.
sourcepub async fn disk_space_bytes(&self) -> Result<isize, DaggerError>
pub async fn disk_space_bytes(&self) -> Result<isize, DaggerError>
The disk space used by the cache entry.
sourcepub async fn id(&self) -> Result<DaggerEngineCacheEntryId, DaggerError>
pub async fn id(&self) -> Result<DaggerEngineCacheEntryId, DaggerError>
A unique identifier for this DaggerEngineCacheEntry.
sourcepub async fn most_recent_use_time_unix_nano(&self) -> Result<isize, DaggerError>
pub async fn most_recent_use_time_unix_nano(&self) -> Result<isize, DaggerError>
The most recent time the cache entry was used, in Unix nanoseconds.