Struct dagger_sdk::DirectoryAsModuleOpts
source · pub struct DirectoryAsModuleOpts<'a> {
pub source_subpath: Option<&'a str>,
}Fields
source_subpath: Option<&'a str>An optional subpath of the directory which contains the module’s source code. This is needed when the module code is in a subdirectory but requires parent directories to be loaded in order to execute. For example, the module source code may need a go.mod, project.toml, package.json, etc. file from a parent directory. If not set, the module source code is loaded from the root of the directory.