pub struct DirectoryAsModuleSourceOptsBuilder<'a> { /* private fields */ }Expand description
Builder for DirectoryAsModuleSourceOpts.
Implementations
Sourceimpl<'a> DirectoryAsModuleSourceOptsBuilder<'a>
impl<'a> DirectoryAsModuleSourceOptsBuilder<'a>
Sourcepub fn source_root_path<VALUE: Into<&'a str>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn source_root_path<VALUE: Into<&'a str>>( &mut self, value: VALUE, ) -> &mut Self
An optional subpath of the directory which contains the module’s configuration file. If not set, the module source code is loaded from the root of the directory.
Sourcepub fn build(
&self,
) -> Result<DirectoryAsModuleSourceOpts<'a>, DirectoryAsModuleSourceOptsBuilderError>
pub fn build( &self, ) -> Result<DirectoryAsModuleSourceOpts<'a>, DirectoryAsModuleSourceOptsBuilderError>