pub struct EngineCache {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl EngineCache
impl EngineCache
Sourcepub fn entry_set(&self) -> EngineCacheEntrySet
pub fn entry_set(&self) -> EngineCacheEntrySet
The current set of entries in the cache
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn entry_set_opts<'a>(
&self,
opts: EngineCacheEntrySetOpts<'a>,
) -> EngineCacheEntrySet
pub fn entry_set_opts<'a>( &self, opts: EngineCacheEntrySetOpts<'a>, ) -> EngineCacheEntrySet
The current set of entries in the cache
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn id(&self) -> Result<EngineCacheId, DaggerError>
pub async fn id(&self) -> Result<EngineCacheId, DaggerError>
A unique identifier for this EngineCache.
Sourcepub async fn max_used_space(&self) -> Result<isize, DaggerError>
pub async fn max_used_space(&self) -> Result<isize, DaggerError>
The maximum bytes to keep in the cache without pruning.
Sourcepub async fn min_free_space(&self) -> Result<isize, DaggerError>
pub async fn min_free_space(&self) -> Result<isize, DaggerError>
The target amount of free disk space the garbage collector will attempt to leave.
Sourcepub async fn prune(&self) -> Result<Void, DaggerError>
pub async fn prune(&self) -> Result<Void, DaggerError>
Prune the cache of releaseable entries
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn prune_opts<'a>(
&self,
opts: EngineCachePruneOpts<'a>,
) -> Result<Void, DaggerError>
pub async fn prune_opts<'a>( &self, opts: EngineCachePruneOpts<'a>, ) -> Result<Void, DaggerError>
Prune the cache of releaseable entries
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn reserved_space(&self) -> Result<isize, DaggerError>
pub async fn reserved_space(&self) -> Result<isize, DaggerError>
The minimum amount of disk space this policy is guaranteed to retain.
Sourcepub async fn target_space(&self) -> Result<isize, DaggerError>
pub async fn target_space(&self) -> Result<isize, DaggerError>
The target number of bytes to keep when pruning.