pub struct EngineCacheEntry {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl EngineCacheEntry
impl EngineCacheEntry
Sourcepub async fn actively_used(&self) -> Result<bool, DaggerError>
pub async fn actively_used(&self) -> Result<bool, DaggerError>
Whether the cache entry is actively being used.
Sourcepub async fn created_time_unix_nano(&self) -> Result<isize, DaggerError>
pub async fn created_time_unix_nano(&self) -> Result<isize, DaggerError>
The time the cache entry was created, in Unix nanoseconds.
Sourcepub async fn description(&self) -> Result<String, DaggerError>
pub async fn description(&self) -> Result<String, DaggerError>
The description of the cache entry.
Sourcepub async fn disk_space_bytes(&self) -> Result<isize, DaggerError>
pub async fn disk_space_bytes(&self) -> Result<isize, DaggerError>
The disk space used by the cache entry.
Sourcepub async fn id(&self) -> Result<EngineCacheEntryId, DaggerError>
pub async fn id(&self) -> Result<EngineCacheEntryId, DaggerError>
A unique identifier for this EngineCacheEntry.
Sourcepub async fn most_recent_use_time_unix_nano(&self) -> Result<isize, DaggerError>
pub async fn most_recent_use_time_unix_nano(&self) -> Result<isize, DaggerError>
The most recent time the cache entry was used, in Unix nanoseconds.
Sourcepub async fn record_type(&self) -> Result<String, DaggerError>
pub async fn record_type(&self) -> Result<String, DaggerError>
The type of the cache record (e.g. regular, internal, frontend, source.local, source.git.checkout, exec.cachemount).