pub struct EngineCacheEntrySet {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl EngineCacheEntrySet
impl EngineCacheEntrySet
Sourcepub async fn disk_space_bytes(&self) -> Result<isize, DaggerError>
pub async fn disk_space_bytes(&self) -> Result<isize, DaggerError>
The total disk space used by the cache entries in this set.
Sourcepub fn entries(&self) -> Vec<EngineCacheEntry>
pub fn entries(&self) -> Vec<EngineCacheEntry>
The list of individual cache entries in the set
Sourcepub async fn entry_count(&self) -> Result<isize, DaggerError>
pub async fn entry_count(&self) -> Result<isize, DaggerError>
The number of cache entries in this set.
Sourcepub async fn id(&self) -> Result<EngineCacheEntrySetId, DaggerError>
pub async fn id(&self) -> Result<EngineCacheEntrySetId, DaggerError>
A unique identifier for this EngineCacheEntrySet.