pub struct EngineCachePruneOpts<'a> {
pub max_used_space: Option<&'a str>,
pub min_free_space: Option<&'a str>,
pub reserved_space: Option<&'a str>,
pub target_space: Option<&'a str>,
pub use_default_policy: Option<bool>,
}Fields
max_used_space: Option<&'a str>Override the maximum disk space to keep before pruning (e.g. “200GB” or “80%”).
min_free_space: Option<&'a str>Override the minimum free disk space target during pruning (e.g. “20GB” or “20%”).
reserved_space: Option<&'a str>Override the minimum disk space to retain during pruning (e.g. “500GB” or “10%”).
target_space: Option<&'a str>Override the target disk space to keep after pruning (e.g. “200GB” or “50%”).
use_default_policy: Option<bool>Use the engine-wide default pruning policy if true, otherwise prune the whole cache of any releasable entries.