pub struct EngineCachePruneOptsBuilder<'a> { /* private fields */ }Expand description
Builder for EngineCachePruneOpts.
Implementations
Sourceimpl<'a> EngineCachePruneOptsBuilder<'a>
impl<'a> EngineCachePruneOptsBuilder<'a>
Sourcepub fn max_estimated_bytes<VALUE: Into<isize>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn max_estimated_bytes<VALUE: Into<isize>>( &mut self, value: VALUE, ) -> &mut Self
Override the maximum structural metadata estimate in absolute bytes. Explicit values must be positive; the configured/default value is used when omitted.
Sourcepub fn max_used_space<VALUE: Into<&'a str>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn max_used_space<VALUE: Into<&'a str>>( &mut self, value: VALUE, ) -> &mut Self
Override the maximum disk space to keep before pruning (e.g. “200GB” or “80%”).
Sourcepub fn min_free_space<VALUE: Into<&'a str>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn min_free_space<VALUE: Into<&'a str>>( &mut self, value: VALUE, ) -> &mut Self
Override the minimum free disk space target during pruning (e.g. “20GB” or “20%”).
Sourcepub fn reserved_space<VALUE: Into<&'a str>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn reserved_space<VALUE: Into<&'a str>>( &mut self, value: VALUE, ) -> &mut Self
Override the minimum disk space to retain during pruning (e.g. “500GB” or “10%”).
Sourcepub fn target_estimated_bytes<VALUE: Into<isize>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn target_estimated_bytes<VALUE: Into<isize>>( &mut self, value: VALUE, ) -> &mut Self
Override the structural metadata estimate to target in absolute bytes. Explicit values must be positive and lower than the resolved maximum; the configured/default value is used when omitted.
Sourcepub fn target_space<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn target_space<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
Override the target disk space to keep after pruning (e.g. “200GB” or “50%”).
Sourcepub fn use_default_policy<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn use_default_policy<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Use enabled engine-wide default disk and structural policies. If no default disk policy is enabled, the disk stage falls back to pruning all releasable disk-cache entries. If false, explicit options select stages; with no options, all releasable disk-cache entries are pruned.
Sourcepub fn build(
&self,
) -> Result<EngineCachePruneOpts<'a>, EngineCachePruneOptsBuilderError>
pub fn build( &self, ) -> Result<EngineCachePruneOpts<'a>, EngineCachePruneOptsBuilderError>