pub struct EnumValueTypeDef {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl EnumValueTypeDef
impl EnumValueTypeDef
Sourcepub async fn deprecated(&self) -> Result<String, DaggerError>
pub async fn deprecated(&self) -> Result<String, DaggerError>
The reason this enum member is deprecated, if any.
Sourcepub async fn description(&self) -> Result<String, DaggerError>
pub async fn description(&self) -> Result<String, DaggerError>
A doc string for the enum member, if any.
Sourcepub async fn id(&self) -> Result<EnumValueTypeDefId, DaggerError>
pub async fn id(&self) -> Result<EnumValueTypeDefId, DaggerError>
A unique identifier for this EnumValueTypeDef.
Sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
The name of the enum member.
Sourcepub fn source_map(&self) -> SourceMap
pub fn source_map(&self) -> SourceMap
The location of this enum member declaration.
Sourcepub async fn value(&self) -> Result<String, DaggerError>
pub async fn value(&self) -> Result<String, DaggerError>
The value of the enum member