pub struct Function {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl Function
impl Function
Sourcepub async fn args(&self) -> Result<Vec<FunctionArg>, DaggerError>
pub async fn args(&self) -> Result<Vec<FunctionArg>, DaggerError>
Arguments accepted by the function, if any.
Sourcepub async fn deprecated(&self) -> Result<String, DaggerError>
pub async fn deprecated(&self) -> Result<String, DaggerError>
The reason this function is deprecated, if any.
Sourcepub async fn description(&self) -> Result<String, DaggerError>
pub async fn description(&self) -> Result<String, DaggerError>
A doc string for the function, if any.
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this Function.
Sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
The name of the function.
Sourcepub fn return_type(&self) -> TypeDef
pub fn return_type(&self) -> TypeDef
The type returned by the function.
Sourcepub async fn source_map(&self) -> Result<Option<SourceMap>, DaggerError>
pub async fn source_map(&self) -> Result<Option<SourceMap>, DaggerError>
The location of this function declaration.
Sourcepub async fn source_module_name(&self) -> Result<String, DaggerError>
pub async fn source_module_name(&self) -> Result<String, DaggerError>
If this function is provided by a module, the name of the module. Unset otherwise.
Sourcepub fn with_agent(&self) -> Function
pub fn with_agent(&self) -> Function
Returns the function with a flag indicating it is an agent middleware.
Sourcepub fn with_arg(
&self,
name: impl Into<String>,
type_def: impl IntoID<Id>,
) -> Function
pub fn with_arg( &self, name: impl Into<String>, type_def: impl IntoID<Id>, ) -> Function
Returns the function with the provided argument
Arguments
name- The name of the argumenttype_def- The type of the argumentopt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn with_arg_opts<'a>(
&self,
name: impl Into<String>,
type_def: impl IntoID<Id>,
opts: FunctionWithArgOpts<'a>,
) -> Function
pub fn with_arg_opts<'a>( &self, name: impl Into<String>, type_def: impl IntoID<Id>, opts: FunctionWithArgOpts<'a>, ) -> Function
Returns the function with the provided argument
Arguments
name- The name of the argumenttype_def- The type of the argumentopt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn with_cache_policy(&self, policy: FunctionCachePolicy) -> Function
pub fn with_cache_policy(&self, policy: FunctionCachePolicy) -> Function
Returns the function updated to use the provided cache policy.
Arguments
policy- The cache policy to use.opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn with_cache_policy_opts<'a>(
&self,
policy: FunctionCachePolicy,
opts: FunctionWithCachePolicyOpts<'a>,
) -> Function
pub fn with_cache_policy_opts<'a>( &self, policy: FunctionCachePolicy, opts: FunctionWithCachePolicyOpts<'a>, ) -> Function
Returns the function updated to use the provided cache policy.
Arguments
policy- The cache policy to use.opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn with_check(&self) -> Function
pub fn with_check(&self) -> Function
Returns the function with a flag indicating it’s a check.
Sourcepub fn with_deprecated(&self) -> Function
pub fn with_deprecated(&self) -> Function
Returns the function with the provided deprecation reason.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn with_deprecated_opts<'a>(
&self,
opts: FunctionWithDeprecatedOpts<'a>,
) -> Function
pub fn with_deprecated_opts<'a>( &self, opts: FunctionWithDeprecatedOpts<'a>, ) -> Function
Returns the function with the provided deprecation reason.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn with_description(&self, description: impl Into<String>) -> Function
pub fn with_description(&self, description: impl Into<String>) -> Function
Sourcepub fn with_generator(&self) -> Function
pub fn with_generator(&self) -> Function
Returns the function with a flag indicating it’s a generator.