pub struct FunctionArg {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl FunctionArg
impl FunctionArg
Sourcepub async fn default_address(&self) -> Result<String, DaggerError>
pub async fn default_address(&self) -> Result<String, DaggerError>
Only applies to arguments of type Container. If the argument is not set, load it from the given address (e.g. alpine:latest)
Sourcepub async fn default_path(&self) -> Result<String, DaggerError>
pub async fn default_path(&self) -> Result<String, DaggerError>
Only applies to arguments of type File or Directory. If the argument is not set, load it from the given path in the context directory
Sourcepub async fn default_value(&self) -> Result<Json, DaggerError>
pub async fn default_value(&self) -> Result<Json, DaggerError>
A default value to use for this argument when not explicitly set by the caller, if any.
Sourcepub async fn deprecated(&self) -> Result<String, DaggerError>
pub async fn deprecated(&self) -> Result<String, DaggerError>
The reason this function is deprecated, if any.
Sourcepub async fn description(&self) -> Result<String, DaggerError>
pub async fn description(&self) -> Result<String, DaggerError>
A doc string for the argument, if any.
Sourcepub async fn id(&self) -> Result<FunctionArgId, DaggerError>
pub async fn id(&self) -> Result<FunctionArgId, DaggerError>
A unique identifier for this FunctionArg.
Sourcepub async fn ignore(&self) -> Result<Vec<String>, DaggerError>
pub async fn ignore(&self) -> Result<Vec<String>, DaggerError>
Only applies to arguments of type Directory. The ignore patterns are applied to the input directory, and matching entries are filtered out, in a cache-efficient manner.
Sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
The name of the argument in lowerCamelCase format.
Sourcepub fn source_map(&self) -> SourceMap
pub fn source_map(&self) -> SourceMap
The location of this arg declaration.