pub struct FunctionCall {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl FunctionCall
impl FunctionCall
Sourcepub async fn id(&self) -> Result<FunctionCallId, DaggerError>
pub async fn id(&self) -> Result<FunctionCallId, DaggerError>
A unique identifier for this FunctionCall.
Sourcepub fn input_args(&self) -> Vec<FunctionCallArgValue>
pub fn input_args(&self) -> Vec<FunctionCallArgValue>
The argument values the function is being invoked with.
Sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
The name of the function being called.
Sourcepub async fn parent(&self) -> Result<Json, DaggerError>
pub async fn parent(&self) -> Result<Json, DaggerError>
The value of the parent object of the function being called. If the function is top-level to the module, this is always an empty object.
Sourcepub async fn parent_name(&self) -> Result<String, DaggerError>
pub async fn parent_name(&self) -> Result<String, DaggerError>
The name of the parent object of the function being called. If the function is top-level to the module, this is the name of the module.
Sourcepub async fn return_error(
&self,
error: impl IntoID<ErrorId>,
) -> Result<Void, DaggerError>
pub async fn return_error( &self, error: impl IntoID<ErrorId>, ) -> Result<Void, DaggerError>
Sourcepub async fn return_value(&self, value: Json) -> Result<Void, DaggerError>
pub async fn return_value(&self, value: Json) -> Result<Void, DaggerError>
Set the return value of the function call to the provided value.
Arguments
value- JSON serialization of the return value.