Struct dagger_sdk::FunctionWithArgOpts
source · pub struct FunctionWithArgOpts<'a> {
pub default_value: Option<Json>,
pub description: Option<&'a str>,
}Fields
default_value: Option<Json>A default value to use for this argument if not explicitly set by the caller, if any
description: Option<&'a str>A doc string for the argument, if any