pub struct GeneratedCode {
    pub proc: Option<Arc<Child>>,
    pub selection: Selection,
    pub graphql_client: DynGraphQLClient,
}

Fields

proc: Option<Arc<Child>>selection: Selectiongraphql_client: DynGraphQLClient

Implementations

source

impl GeneratedCode

source

pub fn code(&self) -> Directory

The directory containing the generated code

source

pub async fn id(&self) -> Result<GeneratedCodeId, DaggerError>

source

pub async fn vcs_generated_paths(&self) -> Result<Vec<String>, DaggerError>

List of paths to mark generated in version control (i.e. .gitattributes)

source

pub async fn vcs_ignored_paths(&self) -> Result<Vec<String>, DaggerError>

List of paths to ignore in version control (i.e. .gitignore)

source

pub fn with_vcs_generated_paths( &self, paths: Vec<impl Into<String>> ) -> GeneratedCode

Set the list of paths to mark generated in version control

source

pub fn with_vcs_ignored_paths( &self, paths: Vec<impl Into<String>> ) -> GeneratedCode

Set the list of paths to ignore in version control