pub struct Generator {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl Generator
impl Generator
Sourcepub async fn completed(&self) -> Result<bool, DaggerError>
pub async fn completed(&self) -> Result<bool, DaggerError>
Whether the generator complete
Sourcepub async fn description(&self) -> Result<String, DaggerError>
pub async fn description(&self) -> Result<String, DaggerError>
Return the description of the generator
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this Generator.
Sourcepub async fn is_empty(&self) -> Result<bool, DaggerError>
pub async fn is_empty(&self) -> Result<bool, DaggerError>
Whether changeset from the last generator run is empty or not
Sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
Return the command name of the generator. Entrypoint targets omit the module prefix.
Sourcepub async fn original_module(&self) -> Result<Option<Module>, DaggerError>
pub async fn original_module(&self) -> Result<Option<Module>, DaggerError>
The module that defined the generator, or null for an engine-defined generator