pub struct GeneratorGroup {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl GeneratorGroup
impl GeneratorGroup
Sourcepub fn changes(&self) -> Changeset
pub fn changes(&self) -> Changeset
The combined changes from the last run of the generators If any conflict occurs, for instance if the same file is modified by multiple generators, or if a file is both modified and deleted, an error is raised and the merge of the changesets will failed. Set ‘continueOnConflicts’ flag to force to merge the changes in a ‘last write wins’ strategy.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn changes_opts(&self, opts: GeneratorGroupChangesOpts) -> Changeset
pub fn changes_opts(&self, opts: GeneratorGroupChangesOpts) -> Changeset
The combined changes from the last run of the generators If any conflict occurs, for instance if the same file is modified by multiple generators, or if a file is both modified and deleted, an error is raised and the merge of the changesets will failed. Set ‘continueOnConflicts’ flag to force to merge the changes in a ‘last write wins’ strategy.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this GeneratorGroup.
Sourcepub async fn is_empty(&self) -> Result<bool, DaggerError>
pub async fn is_empty(&self) -> Result<bool, DaggerError>
Whether the generated changeset from the last run is empty or not
Sourcepub async fn list(&self) -> Result<Vec<Generator>, DaggerError>
pub async fn list(&self) -> Result<Vec<Generator>, DaggerError>
Return a list of individual generators and their details
Sourcepub async fn load_failures(&self) -> Result<Vec<String>, DaggerError>
pub async fn load_failures(&self) -> Result<Vec<String>, DaggerError>
Load failures tolerated while collecting the generators. Empty unless a workspace module could not be loaded during an unscoped ‘dagger generate’ (no selector), where load failures are tolerated so the modules that do load still generate. Each entry is a human-readable error message. An explicit selector keeps failing hard instead.
Sourcepub fn run(&self) -> GeneratorGroup
pub fn run(&self) -> GeneratorGroup
Execute all selected generators
Sourcepub fn workspace(&self) -> Workspace
pub fn workspace(&self) -> Workspace
The workspace with the combined output from the last generator run
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn workspace_opts(&self, opts: GeneratorGroupWorkspaceOpts) -> Workspace
pub fn workspace_opts(&self, opts: GeneratorGroupWorkspaceOpts) -> Workspace
The workspace with the combined output from the last generator run
Arguments
opt- optional argument, see inner type for documentation, use_opts to use