pub struct GitBundle {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl GitBundle
impl GitBundle
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this GitBundle.
Sourcepub async fn object_format(&self) -> Result<String, DaggerError>
pub async fn object_format(&self) -> Result<String, DaggerError>
Object format capability: sha1 or sha256.
Sourcepub async fn prerequisite_sh_as(&self) -> Result<Vec<String>, DaggerError>
pub async fn prerequisite_sh_as(&self) -> Result<Vec<String>, DaggerError>
Commits that must already exist wherever this bundle is applied.
Sourcepub async fn refs(&self) -> Result<Vec<GitBundleRef>, DaggerError>
pub async fn refs(&self) -> Result<Vec<GitBundleRef>, DaggerError>
Refs advertised by the bundle and the object IDs they resolve to.
Sourcepub fn validate(&self) -> GitBundle
pub fn validate(&self) -> GitBundle
Perform full structural verification of the bundle and error if it is malformed.
Sourcepub async fn version(&self) -> Result<isize, DaggerError>
pub async fn version(&self) -> Result<isize, DaggerError>
Bundle format version (2 or 3).