GitCommit

Struct GitCommit 

pub struct GitCommit {
    pub proc: Option<Arc<DaggerSessionProc>>,
    pub selection: Selection,
    pub graphql_client: DynGraphQLClient,
}

Fields

proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClient

Implementations

Source

impl GitCommit

pub async fn ancestor_release_tag(&self) -> Result<Option<GitRef>, DaggerError>

The latest semver release tag reachable from this commit.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
pub async fn ancestor_release_tag_opts( &self, opts: GitCommitAncestorReleaseTagOpts, ) -> Result<Option<GitRef>, DaggerError>

The latest semver release tag reachable from this commit.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
pub async fn author_email(&self) -> Result<String, DaggerError>

Git author email.

pub async fn author_name(&self) -> Result<String, DaggerError>

Git author name.

pub async fn authored_date(&self) -> Result<String, DaggerError>

Git author date, in RFC3339 format.

pub fn changes(&self) -> Changeset

Returns the changes from the first parent to this commit, excluding Git metadata. Root commits are compared with an empty tree. Merge commits are compared with their first parent, not a merge base.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
pub fn changes_opts(&self, opts: GitCommitChangesOpts) -> Changeset

Returns the changes from the first parent to this commit, excluding Git metadata. Root commits are compared with an empty tree. Merge commits are compared with their first parent, not a merge base.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
pub async fn committed_date(&self) -> Result<String, DaggerError>

Git committer date, in RFC3339 format.

pub async fn committer_email(&self) -> Result<String, DaggerError>

Git committer email.

pub async fn committer_name(&self) -> Result<String, DaggerError>

Git committer name.

pub async fn id(&self) -> Result<Id, DaggerError>

A unique identifier for this GitCommit.

pub async fn message(&self) -> Result<String, DaggerError>

Full commit message.

pub async fn message_body(&self) -> Result<String, DaggerError>

Commit message body, excluding the headline.

pub async fn message_headline(&self) -> Result<String, DaggerError>

First line of the commit message.

pub async fn parent_shas(&self) -> Result<Vec<String>, DaggerError>

Parent commit SHAs.

pub async fn release_tag(&self) -> Result<Option<GitRef>, DaggerError>

The latest semver release tag that points directly at this commit.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
pub async fn release_tag_opts( &self, opts: GitCommitReleaseTagOpts, ) -> Result<Option<GitRef>, DaggerError>

The latest semver release tag that points directly at this commit.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
pub async fn sha(&self) -> Result<String, DaggerError>

The full commit SHA.

pub async fn short_sha(&self) -> Result<String, DaggerError>

The abbreviated commit SHA.

pub fn tree(&self) -> Directory

The filesystem tree at this commit.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
pub fn tree_opts(&self, opts: GitCommitTreeOpts) -> Directory

The filesystem tree at this commit.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use