pub struct GitCommitChangesOpts {
pub against: Option<Id>,
}Fields
against: Option<Id>Use this commit as the comparison base instead of the first parent. The comparison commit may belong to an unrelated history or repository.