pub struct GitCommitChangesOptsBuilder { /* private fields */ }Expand description
Builder for GitCommitChangesOpts.
Implementations
Sourceimpl GitCommitChangesOptsBuilder
impl GitCommitChangesOptsBuilder
Sourcepub fn against<VALUE: Into<Id>>(&mut self, value: VALUE) -> &mut Self
pub fn against<VALUE: Into<Id>>(&mut self, value: VALUE) -> &mut Self
Use this commit as the comparison base instead of the first parent. The comparison commit may belong to an unrelated history or repository.
Sourcepub fn build(
&self,
) -> Result<GitCommitChangesOpts, GitCommitChangesOptsBuilderError>
pub fn build( &self, ) -> Result<GitCommitChangesOpts, GitCommitChangesOptsBuilderError>