pub struct GitModuleSource {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl GitModuleSource
impl GitModuleSource
Sourcepub async fn clone_ref(&self) -> Result<String, DaggerError>
pub async fn clone_ref(&self) -> Result<String, DaggerError>
The ref to clone the root of the git repo from
Sourcepub async fn commit(&self) -> Result<String, DaggerError>
pub async fn commit(&self) -> Result<String, DaggerError>
The resolved commit of the git repo this source points to.
Sourcepub fn context_directory(&self) -> Directory
pub fn context_directory(&self) -> Directory
The directory containing everything needed to load load and use the module.
Sourcepub async fn html_repo_url(&self) -> Result<String, DaggerError>
pub async fn html_repo_url(&self) -> Result<String, DaggerError>
The URL to access the web view of the repository (e.g., GitHub, GitLab, Bitbucket)
Sourcepub async fn html_url(&self) -> Result<String, DaggerError>
pub async fn html_url(&self) -> Result<String, DaggerError>
The URL to the source’s git repo in a web browser
Sourcepub async fn id(&self) -> Result<GitModuleSourceId, DaggerError>
pub async fn id(&self) -> Result<GitModuleSourceId, DaggerError>
A unique identifier for this GitModuleSource.
Sourcepub async fn root(&self) -> Result<String, DaggerError>
pub async fn root(&self) -> Result<String, DaggerError>
The clean module name of the root of the module
Sourcepub async fn root_subpath(&self) -> Result<String, DaggerError>
pub async fn root_subpath(&self) -> Result<String, DaggerError>
The path to the root of the module source under the context directory. This directory contains its configuration file. It also contains its source code (possibly as a subdirectory).
Sourcepub async fn version(&self) -> Result<String, DaggerError>
pub async fn version(&self) -> Result<String, DaggerError>
The specified version of the git repo this source points to.