pub struct GitRepository {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl GitRepository
impl GitRepository
Sourcepub async fn branches(&self) -> Result<Vec<String>, DaggerError>
pub async fn branches(&self) -> Result<Vec<String>, DaggerError>
branches that match any of the given glob patterns.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn branches_opts<'a>(
&self,
opts: GitRepositoryBranchesOpts<'a>,
) -> Result<Vec<String>, DaggerError>
pub async fn branches_opts<'a>( &self, opts: GitRepositoryBranchesOpts<'a>, ) -> Result<Vec<String>, DaggerError>
branches that match any of the given glob patterns.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn commit(&self, id: impl Into<String>) -> GitRef
pub fn commit(&self, id: impl Into<String>) -> GitRef
Returns details of a commit.
Arguments
id- Identifier of the commit (e.g., “b6315d8f2810962c601af73f86831f6866ea798b”).
Sourcepub async fn id(&self) -> Result<GitRepositoryId, DaggerError>
pub async fn id(&self) -> Result<GitRepositoryId, DaggerError>
A unique identifier for this GitRepository.
Sourcepub fn latest_version(&self) -> GitRef
pub fn latest_version(&self) -> GitRef
Returns details for the latest semver tag.
Sourcepub fn ref(&self, name: impl Into<String>) -> GitRef
pub fn ref(&self, name: impl Into<String>) -> GitRef
Returns details of a ref.
Arguments
name- Ref’s name (can be a commit identifier, a tag name, a branch name, or a fully-qualified ref).
tags that match any of the given glob patterns.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
tags that match any of the given glob patterns.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn uncommitted(&self) -> Changeset
pub fn uncommitted(&self) -> Changeset
Returns the changeset of uncommitted changes in the git repository.
Sourcepub async fn url(&self) -> Result<String, DaggerError>
pub async fn url(&self) -> Result<String, DaggerError>
The URL of the git repository.