pub struct HealthcheckConfig {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl HealthcheckConfig
impl HealthcheckConfig
Sourcepub async fn id(&self) -> Result<HealthcheckConfigId, DaggerError>
pub async fn id(&self) -> Result<HealthcheckConfigId, DaggerError>
A unique identifier for this HealthcheckConfig.
Sourcepub async fn interval(&self) -> Result<String, DaggerError>
pub async fn interval(&self) -> Result<String, DaggerError>
Interval between running healthcheck. Example:30s
Sourcepub async fn retries(&self) -> Result<isize, DaggerError>
pub async fn retries(&self) -> Result<isize, DaggerError>
The maximum number of consecutive failures before the container is marked as unhealthy. Example:3
Sourcepub async fn shell(&self) -> Result<bool, DaggerError>
pub async fn shell(&self) -> Result<bool, DaggerError>
Healthcheck command is a shell command.
Sourcepub async fn start_interval(&self) -> Result<String, DaggerError>
pub async fn start_interval(&self) -> Result<String, DaggerError>
StartInterval configures the duration between checks during the startup phase. Example:5s
Sourcepub async fn start_period(&self) -> Result<String, DaggerError>
pub async fn start_period(&self) -> Result<String, DaggerError>
StartPeriod allows for failures during this initial startup period which do not count towards maximum number of retries. Example:0s
Sourcepub async fn timeout(&self) -> Result<String, DaggerError>
pub async fn timeout(&self) -> Result<String, DaggerError>
Healthcheck timeout. Example:3s