pub struct LlmContentBlock {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl LlmContentBlock
impl LlmContentBlock
Sourcepub async fn arguments(&self) -> Result<Json, DaggerError>
pub async fn arguments(&self) -> Result<Json, DaggerError>
The arguments passed to the tool, JSON-encoded (for TOOL_CALL kind).
Sourcepub async fn call_id(&self) -> Result<String, DaggerError>
pub async fn call_id(&self) -> Result<String, DaggerError>
The unique ID of a tool call (for TOOL_CALL or TOOL_RESULT kinds).
Sourcepub async fn errored(&self) -> Result<bool, DaggerError>
pub async fn errored(&self) -> Result<bool, DaggerError>
Whether the tool call resulted in an error (for TOOL_RESULT kind).
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this LLMContentBlock.
Sourcepub async fn kind(&self) -> Result<LlmContentBlockKind, DaggerError>
pub async fn kind(&self) -> Result<LlmContentBlockKind, DaggerError>
The kind of content block, which determines the other populated fields.
Sourcepub async fn signature(&self) -> Result<String, DaggerError>
pub async fn signature(&self) -> Result<String, DaggerError>
Provider-specific opaque data (e.g. Anthropic thinking signature). Preserve it when reconstructing a conversation.
Sourcepub async fn text(&self) -> Result<String, DaggerError>
pub async fn text(&self) -> Result<String, DaggerError>
Text content (for TEXT, THINKING, or TOOL_RESULT kinds).
Sourcepub async fn tool_name(&self) -> Result<String, DaggerError>
pub async fn tool_name(&self) -> Result<String, DaggerError>
The name of the tool called (for TOOL_CALL kind).