pub struct LlmWithModelOptsBuilder<'a> { /* private fields */ }Expand description
Builder for LlmWithModelOpts.
Implementations
Sourceimpl<'a> LlmWithModelOptsBuilder<'a>
impl<'a> LlmWithModelOptsBuilder<'a>
Sourcepub fn provider<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn provider<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
The provider serving the model, e.g. “openai”. Overrides the provider otherwise inferred from the model name — useful when the name matches no known pattern (e.g. a fine-tune), or matches the wrong one.
Sourcepub fn build(
&self,
) -> Result<LlmWithModelOpts<'a>, LlmWithModelOptsBuilderError>
pub fn build( &self, ) -> Result<LlmWithModelOpts<'a>, LlmWithModelOptsBuilderError>