pub struct LocalModuleSource {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl LocalModuleSource
impl LocalModuleSource
Sourcepub fn context_directory(&self) -> Directory
pub fn context_directory(&self) -> Directory
The directory containing everything needed to load load and use the module.
Sourcepub async fn id(&self) -> Result<LocalModuleSourceId, DaggerError>
pub async fn id(&self) -> Result<LocalModuleSourceId, DaggerError>
A unique identifier for this LocalModuleSource.
Sourcepub async fn rel_host_path(&self) -> Result<String, DaggerError>
pub async fn rel_host_path(&self) -> Result<String, DaggerError>
The relative path to the module root from the host directory
Sourcepub async fn root_subpath(&self) -> Result<String, DaggerError>
pub async fn root_subpath(&self) -> Result<String, DaggerError>
The path to the root of the module source under the context directory. This directory contains its configuration file. It also contains its source code (possibly as a subdirectory).