Struct dagger_sdk::ModuleConfig
source · pub struct ModuleConfig {
pub proc: Option<Arc<Child>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<Child>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
sourceimpl ModuleConfig
impl ModuleConfig
sourcepub async fn dependencies(&self) -> Result<Vec<String>, DaggerError>
pub async fn dependencies(&self) -> Result<Vec<String>, DaggerError>
Modules that this module depends on.
sourcepub async fn exclude(&self) -> Result<Vec<String>, DaggerError>
pub async fn exclude(&self) -> Result<Vec<String>, DaggerError>
Exclude these file globs when loading the module root.
sourcepub async fn include(&self) -> Result<Vec<String>, DaggerError>
pub async fn include(&self) -> Result<Vec<String>, DaggerError>
Include only these file globs when loading the module root.
sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
The name of the module.
sourcepub async fn root(&self) -> Result<String, DaggerError>
pub async fn root(&self) -> Result<String, DaggerError>
The root directory of the module’s project, which may be above the module source code.
sourcepub async fn sdk(&self) -> Result<String, DaggerError>
pub async fn sdk(&self) -> Result<String, DaggerError>
Either the name of a built-in SDK (‘go’, ‘python’, etc.) OR a module reference pointing to the SDK’s module implementation.