pub struct ModuleServeOpts {
pub entrypoint: Option<bool>,
pub include_dependencies: Option<bool>,
}Fields
entrypoint: Option<bool>Install the module as the entrypoint, promoting its main-object methods onto the Query root
include_dependencies: Option<bool>Expose the dependencies of this module to the client