pub struct ObjectTypeDef {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl ObjectTypeDef
impl ObjectTypeDef
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The function used to construct new instances of this object, if any
Sourcepub async fn deprecated(&self) -> Result<String, DaggerError>
pub async fn deprecated(&self) -> Result<String, DaggerError>
The reason this enum member is deprecated, if any.
Sourcepub async fn description(&self) -> Result<String, DaggerError>
pub async fn description(&self) -> Result<String, DaggerError>
The doc string for the object, if any.
Sourcepub fn fields(&self) -> Vec<FieldTypeDef>
pub fn fields(&self) -> Vec<FieldTypeDef>
Static fields defined on this object, if any.
Sourcepub async fn id(&self) -> Result<ObjectTypeDefId, DaggerError>
pub async fn id(&self) -> Result<ObjectTypeDefId, DaggerError>
A unique identifier for this ObjectTypeDef.
Sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
The name of the object.
Sourcepub fn source_map(&self) -> SourceMap
pub fn source_map(&self) -> SourceMap
The location of this object declaration.
Sourcepub async fn source_module_name(&self) -> Result<String, DaggerError>
pub async fn source_module_name(&self) -> Result<String, DaggerError>
If this ObjectTypeDef is associated with a Module, the name of the module. Unset otherwise.