pub struct QueryCurrentTypeDefsOptsBuilder { /* private fields */ }Expand description
Builder for QueryCurrentTypeDefsOpts.
Implementations
Sourceimpl QueryCurrentTypeDefsOptsBuilder
impl QueryCurrentTypeDefsOptsBuilder
Sourcepub fn hide_core<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn hide_core<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Strip core API functions from the Query type, leaving only module-sourced functions (constructors, entrypoint proxies, etc.). Core types (Container, Directory, etc.) are kept so return types and method chaining still work.
Sourcepub fn build(
&self,
) -> Result<QueryCurrentTypeDefsOpts, QueryCurrentTypeDefsOptsBuilderError>
pub fn build( &self, ) -> Result<QueryCurrentTypeDefsOpts, QueryCurrentTypeDefsOptsBuilderError>