pub struct QueryGitOpts<'a> {
pub experimental_service_host: Option<Id>,
pub http_auth_header: Option<Id>,
pub http_auth_token: Option<Id>,
pub http_auth_username: Option<&'a str>,
pub keep_git_dir: Option<bool>,
pub ssh_auth_socket: Option<Id>,
pub ssh_known_hosts: Option<&'a str>,
}Fields
experimental_service_host: Option<Id>A service which must be started before the repo is fetched.
http_auth_header: Option<Id>Secret used to populate the Authorization HTTP header
http_auth_token: Option<Id>Secret used to populate the password during basic HTTP Authorization
http_auth_username: Option<&'a str>Username used to populate the password during basic HTTP Authorization
keep_git_dir: Option<bool>DEPRECATED: Set to true to keep .git directory.
ssh_auth_socket: Option<Id>Set SSH auth socket
ssh_known_hosts: Option<&'a str>Set SSH known hosts