pub struct QueryModuleSourceOpts<'a> {
pub allow_not_exists: Option<bool>,
pub disable_find_up: Option<bool>,
pub ref_pin: Option<&'a str>,
pub require_kind: Option<ModuleSourceKind>,
pub version: Option<&'a str>,
}Fields
allow_not_exists: Option<bool>If true, do not error out if the provided ref string is a local path and does not exist yet. Useful when initializing new modules in directories that don’t exist yet.
disable_find_up: Option<bool>If true, do not attempt to find a module config file in a parent directory of the provided path. Only relevant for local module sources.
ref_pin: Option<&'a str>The pinned version of the module source
require_kind: Option<ModuleSourceKind>If set, error out if the ref string is not of the provided requireKind.
version: Option<&'a str>Version query for a Git module source.