pub struct QueryModuleSourceOptsBuilder<'a> { /* private fields */ }Expand description
Builder for QueryModuleSourceOpts.
Implementations
Sourceimpl<'a> QueryModuleSourceOptsBuilder<'a>
impl<'a> QueryModuleSourceOptsBuilder<'a>
Sourcepub fn ref_pin<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn ref_pin<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
The pinned version of the module source
Sourcepub fn rel_host_path<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn rel_host_path<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
The relative path to the module root from the host directory
Sourcepub fn stable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn stable<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If true, enforce that the source is a stable version for source kinds that support versioning.
Sourcepub fn build(
&self,
) -> Result<QueryModuleSourceOpts<'a>, QueryModuleSourceOptsBuilderError>
pub fn build( &self, ) -> Result<QueryModuleSourceOpts<'a>, QueryModuleSourceOptsBuilderError>