pub struct QuerySshfsVolumeOpts<'a> {
pub cache_key: Option<&'a str>,
pub experimental_service_host: Option<Id>,
pub insecure_skip_host_key_check: Option<bool>,
pub known_hosts: Option<Id>,
}Fields
cache_key: Option<&'a str>Optional cache equivalence key. If set, volumes with the same cacheKey may be considered equivalent for cache lookups, still subject to their resource dependencies.
experimental_service_host: Option<Id>Service to use as the SSHFS network endpoint while verifying the original host key.
insecure_skip_host_key_check: Option<bool>Disable SSH host key verification. This is insecure and must be explicitly opted into.
known_hosts: Option<Id>known_hosts material used to verify the remote host key. Required unless insecureSkipHostKeyCheck is true.