pub struct QuerySshfsVolumeOptsBuilder<'a> { /* private fields */ }Expand description
Builder for QuerySshfsVolumeOpts.
Implementations
Sourceimpl<'a> QuerySshfsVolumeOptsBuilder<'a>
impl<'a> QuerySshfsVolumeOptsBuilder<'a>
Sourcepub fn cache_key<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn cache_key<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
Optional cache equivalence key. If set, volumes with the same cacheKey may be considered equivalent for cache lookups, still subject to their resource dependencies.
Sourcepub fn experimental_service_host<VALUE: Into<Id>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn experimental_service_host<VALUE: Into<Id>>( &mut self, value: VALUE, ) -> &mut Self
Service to use as the SSHFS network endpoint while verifying the original host key.
Sourcepub fn insecure_skip_host_key_check<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn insecure_skip_host_key_check<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Disable SSH host key verification. This is insecure and must be explicitly opted into.
Sourcepub fn known_hosts<VALUE: Into<Id>>(&mut self, value: VALUE) -> &mut Self
pub fn known_hosts<VALUE: Into<Id>>(&mut self, value: VALUE) -> &mut Self
known_hosts material used to verify the remote host key. Required unless insecureSkipHostKeyCheck is true.
Sourcepub fn build(
&self,
) -> Result<QuerySshfsVolumeOpts<'a>, QuerySshfsVolumeOptsBuilderError>
pub fn build( &self, ) -> Result<QuerySshfsVolumeOpts<'a>, QuerySshfsVolumeOptsBuilderError>