pub struct SdkConfig {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl SdkConfig
impl SdkConfig
Sourcepub async fn debug(&self) -> Result<bool, DaggerError>
pub async fn debug(&self) -> Result<bool, DaggerError>
Whether to start the SDK runtime in debug mode with an interactive terminal.
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this SDKConfig.
Sourcepub async fn source(&self) -> Result<String, DaggerError>
pub async fn source(&self) -> Result<String, DaggerError>
Source of the SDK. Either a name of a builtin SDK or a module source ref string pointing to the SDK’s implementation.