pub struct Service {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl Service
impl Service
Sourcepub async fn endpoint(&self) -> Result<String, DaggerError>
pub async fn endpoint(&self) -> Result<String, DaggerError>
Retrieves an endpoint that clients can use to reach this container. If no port is specified, the first exposed port is used. If none exist an error is returned. If a scheme is specified, a URL is returned. Otherwise, a host:port pair is returned.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn endpoint_opts<'a>(
&self,
opts: ServiceEndpointOpts<'a>,
) -> Result<String, DaggerError>
pub async fn endpoint_opts<'a>( &self, opts: ServiceEndpointOpts<'a>, ) -> Result<String, DaggerError>
Retrieves an endpoint that clients can use to reach this container. If no port is specified, the first exposed port is used. If none exist an error is returned. If a scheme is specified, a URL is returned. Otherwise, a host:port pair is returned.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn hostname(&self) -> Result<String, DaggerError>
pub async fn hostname(&self) -> Result<String, DaggerError>
Retrieves a hostname which can be used by clients to reach this container.
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this Service.
Sourcepub async fn ports(&self) -> Result<Vec<Port>, DaggerError>
pub async fn ports(&self) -> Result<Vec<Port>, DaggerError>
Retrieves the list of ports provided by the service.
Sourcepub async fn start(&self) -> Result<Service, DaggerError>
pub async fn start(&self) -> Result<Service, DaggerError>
Start the service and wait for its health checks to succeed. Services bound to a Container do not need to be manually started.
Sourcepub async fn stop(&self) -> Result<Service, DaggerError>
pub async fn stop(&self) -> Result<Service, DaggerError>
Stop the service.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn stop_opts(
&self,
opts: ServiceStopOpts,
) -> Result<Service, DaggerError>
pub async fn stop_opts( &self, opts: ServiceStopOpts, ) -> Result<Service, DaggerError>
Stop the service.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn sync(&self) -> Result<Service, DaggerError>
pub async fn sync(&self) -> Result<Service, DaggerError>
Forces evaluation of the pipeline in the engine.
Sourcepub fn terminal(&self) -> Service
pub fn terminal(&self) -> Service
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn terminal_opts<'a>(&self, opts: ServiceTerminalOpts<'a>) -> Service
pub fn terminal_opts<'a>(&self, opts: ServiceTerminalOpts<'a>) -> Service
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn up(&self) -> Result<Void, DaggerError>
pub async fn up(&self) -> Result<Void, DaggerError>
Creates a tunnel that forwards traffic from the caller’s network to this service.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn up_opts(&self, opts: ServiceUpOpts) -> Result<Void, DaggerError>
pub async fn up_opts(&self, opts: ServiceUpOpts) -> Result<Void, DaggerError>
Creates a tunnel that forwards traffic from the caller’s network to this service.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use