pub struct WorkspaceMigration {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl WorkspaceMigration
impl WorkspaceMigration
Sourcepub async fn config_file(&self) -> Result<String, DaggerError>
pub async fn config_file(&self) -> Result<String, DaggerError>
Native workspace config path after migration, relative to the workspace root. Empty if no workspace config exists.
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this WorkspaceMigration.
Sourcepub async fn module_candidates(&self) -> Result<Vec<String>, DaggerError>
pub async fn module_candidates(&self) -> Result<Vec<String>, DaggerError>
Unselected legacy module directories relative to the workspace root. Candidates can include fixtures.
Sourcepub async fn steps(&self) -> Result<Vec<WorkspaceMigrationStep>, DaggerError>
pub async fn steps(&self) -> Result<Vec<WorkspaceMigrationStep>, DaggerError>
Logical migration steps, each identified by a stable code.