pub struct WorkspaceModuleSetting {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl WorkspaceModuleSetting
impl WorkspaceModuleSetting
Sourcepub async fn description(&self) -> Result<String, DaggerError>
pub async fn description(&self) -> Result<String, DaggerError>
The constructor argument description.
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this WorkspaceModuleSetting.
Sourcepub async fn is_list(&self) -> Result<bool, DaggerError>
pub async fn is_list(&self) -> Result<bool, DaggerError>
Whether the setting accepts a list of values.
Sourcepub async fn is_object(&self) -> Result<bool, DaggerError>
pub async fn is_object(&self) -> Result<bool, DaggerError>
Whether the setting is an object type resolved from an address string (Container, Directory, File, Secret, Service, …), which may be a module reference.
Sourcepub async fn key(&self) -> Result<String, DaggerError>
pub async fn key(&self) -> Result<String, DaggerError>
The setting key.
Sourcepub async fn value(&self) -> Result<String, DaggerError>
pub async fn value(&self) -> Result<String, DaggerError>
The configured value after applying the selected workspace environment, or empty when unset.