pub struct WorkspaceWithUpdatedClientsOpts<'a> {
pub all: Option<bool>,
pub modules: Option<Vec<&'a str>>,
pub sdk: Option<&'a str>,
}Fields
all: Option<bool>Select clients in every scope instead of only the scopes containing the workspace cwd.
modules: Option<Vec<&'a str>>Recorded client targets to update. All targets in the selected scopes are updated when omitted.
sdk: Option<&'a str>Optional SDK name. All installed SDK modules are selected when omitted.