pub struct WorkspaceWithUpdatedClientsOptsBuilder<'a> { /* private fields */ }Expand description
Builder for WorkspaceWithUpdatedClientsOpts.
Implementations
Sourceimpl<'a> WorkspaceWithUpdatedClientsOptsBuilder<'a>
impl<'a> WorkspaceWithUpdatedClientsOptsBuilder<'a>
Sourcepub fn all<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn all<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Select clients in every scope instead of only the scopes containing the workspace cwd.
Sourcepub fn modules<VALUE: Into<Vec<&'a str>>>(&mut self, value: VALUE) -> &mut Self
pub fn modules<VALUE: Into<Vec<&'a str>>>(&mut self, value: VALUE) -> &mut Self
Recorded client targets to update. All targets in the selected scopes are updated when omitted.
Sourcepub fn sdk<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn sdk<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
Optional SDK name. All installed SDK modules are selected when omitted.
Sourcepub fn build(
&self,
) -> Result<WorkspaceWithUpdatedClientsOpts<'a>, WorkspaceWithUpdatedClientsOptsBuilderError>
pub fn build( &self, ) -> Result<WorkspaceWithUpdatedClientsOpts<'a>, WorkspaceWithUpdatedClientsOptsBuilderError>