pub trait Exportable {
// Required methods
fn export(
&self,
path: impl Into<String>,
) -> impl Future<Output = Result<String, DaggerError>> + Send;
fn id(&self) -> impl Future<Output = Result<Id, DaggerError>> + Send;
}Expand description
An object that can be exported to the host. Calling export writes the object to a path on the host filesystem and returns the path that was written.
Required Methods
fn export( &self, path: impl Into<String>, ) -> impl Future<Output = Result<String, DaggerError>> + Send
fn id(&self) -> impl Future<Output = Result<Id, DaggerError>> + Send
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".