pub struct ContainerFromOpts {
pub registry_service: Option<Id>,
}Fields
registry_service: Option<Id>Service to use as the registry endpoint for the image address. The service will be started only for this pull.