pub struct ContainerPublishOpts {
pub forced_compression: Option<ImageLayerCompression>,
pub insecure_skip_tls_verify: Option<bool>,
pub media_types: Option<ImageMediaTypes>,
pub platform_variants: Option<Vec<Id>>,
pub protocol: Option<RegistryProtocol>,
pub registry_service: Option<Id>,
}Fields
forced_compression: Option<ImageLayerCompression>Force each layer of the published image to use the specified compression algorithm. If this is unset, then if a layer already has a compressed blob in the engine’s cache, that will be used (this can result in a mix of compression algorithms for different layers). If this is unset and a layer has no compressed blob in the engine’s cache, then it will be compressed using Gzip.
insecure_skip_tls_verify: Option<bool>Allow HTTPS registry communication without verifying the server certificate.
media_types: Option<ImageMediaTypes>Use the specified media types for the published image’s layers. Defaults to “OCI”, which is compatible with most recent registries, but “Docker” may be needed for older registries without OCI support.
platform_variants: Option<Vec<Id>>Identifiers for other platform specific containers. Used for multi-platform image.
protocol: Option<RegistryProtocol>Protocol to use for registry communication. Defaults to “HTTPS”. Use “HTTP” only for plain HTTP registries.
registry_service: Option<Id>Service to use as the registry endpoint for the image address. The service will be started only for this push.