pub struct ContainerPublishOptsBuilder { /* private fields */ }Expand description
Builder for ContainerPublishOpts.
Implementations
Sourceimpl ContainerPublishOptsBuilder
impl ContainerPublishOptsBuilder
Sourcepub fn forced_compression<VALUE: Into<ImageLayerCompression>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn forced_compression<VALUE: Into<ImageLayerCompression>>( &mut self, value: VALUE, ) -> &mut Self
Force each layer of the published image to use the specified compression algorithm. If this is unset, then if a layer already has a compressed blob in the engine’s cache, that will be used (this can result in a mix of compression algorithms for different layers). If this is unset and a layer has no compressed blob in the engine’s cache, then it will be compressed using Gzip.
Sourcepub fn media_types<VALUE: Into<ImageMediaTypes>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn media_types<VALUE: Into<ImageMediaTypes>>( &mut self, value: VALUE, ) -> &mut Self
Use the specified media types for the published image’s layers. Defaults to “OCI”, which is compatible with most recent registries, but “Docker” may be needed for older registries without OCI support.
Sourcepub fn platform_variants<VALUE: Into<Vec<Id>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn platform_variants<VALUE: Into<Vec<Id>>>( &mut self, value: VALUE, ) -> &mut Self
Identifiers for other platform specific containers. Used for multi-platform image.
Sourcepub fn registry_service<VALUE: Into<Id>>(&mut self, value: VALUE) -> &mut Self
pub fn registry_service<VALUE: Into<Id>>(&mut self, value: VALUE) -> &mut Self
Service to use as the registry endpoint for the image address. The service will be started only for this push.
Sourcepub fn build(
&self,
) -> Result<ContainerPublishOpts, ContainerPublishOptsBuilderError>
pub fn build( &self, ) -> Result<ContainerPublishOpts, ContainerPublishOptsBuilderError>