pub struct ContainerPublishOptsBuilder { /* private fields */ }
Builder for ContainerPublishOpts.

Implementations

source

impl ContainerPublishOptsBuilder

source

pub fn forced_compression<VALUE: Into<ImageLayerCompression>>( &mut self, value: VALUE ) -> &mut Self

Force each layer of the published image to use the specified compression algorithm. If this is unset, then if a layer already has a compressed blob in the engine’s cache, that will be used (this can result in a mix of compression algorithms for different layers). If this is unset and a layer has no compressed blob in the engine’s cache, then it will be compressed using Gzip.

source

pub fn media_types<VALUE: Into<ImageMediaTypes>>( &mut self, value: VALUE ) -> &mut Self

Use the specified media types for the published image’s layers. Defaults to OCI, which is largely compatible with most recent registries, but Docker may be needed for older registries without OCI support.

source

pub fn platform_variants<VALUE: Into<Vec<ContainerId>>>( &mut self, value: VALUE ) -> &mut Self

Identifiers for other platform specific containers. Used for multi-platform image.

source

pub fn build( &self ) -> Result<ContainerPublishOpts, ContainerPublishOptsBuilderError>

Builds a new ContainerPublishOpts.

Errors

If a required field has not been initialized.