Struct dagger_sdk::ContainerWithExecOptsBuilder
source · pub struct ContainerWithExecOptsBuilder<'a> { /* private fields */ }Expand description
Builder for ContainerWithExecOpts.
Implementations
sourceimpl<'a> ContainerWithExecOptsBuilder<'a>
impl<'a> ContainerWithExecOptsBuilder<'a>
sourcepub fn experimental_privileged_nesting<VALUE: Into<bool>>(
&mut self,
value: VALUE
) -> &mut Self
pub fn experimental_privileged_nesting<VALUE: Into<bool>>( &mut self, value: VALUE ) -> &mut Self
Provides dagger access to the executed command. Do not use this option unless you trust the command being executed. The command being executed WILL BE GRANTED FULL ACCESS TO YOUR HOST FILESYSTEM.
sourcepub fn insecure_root_capabilities<VALUE: Into<bool>>(
&mut self,
value: VALUE
) -> &mut Self
pub fn insecure_root_capabilities<VALUE: Into<bool>>( &mut self, value: VALUE ) -> &mut Self
Execute the command with all root capabilities. This is similar to running a command
with “sudo” or executing docker run with the --privileged flag. Containerization
does not provide any security guarantees when using this option. It should only be used
when absolutely necessary and only with trusted commands.
sourcepub fn redirect_stderr<VALUE: Into<&'a str>>(
&mut self,
value: VALUE
) -> &mut Self
pub fn redirect_stderr<VALUE: Into<&'a str>>( &mut self, value: VALUE ) -> &mut Self
Redirect the command’s standard error to a file in the container (e.g., “/tmp/stderr”).
sourcepub fn redirect_stdout<VALUE: Into<&'a str>>(
&mut self,
value: VALUE
) -> &mut Self
pub fn redirect_stdout<VALUE: Into<&'a str>>( &mut self, value: VALUE ) -> &mut Self
Redirect the command’s standard output to a file in the container (e.g., “/tmp/stdout”).
sourcepub fn skip_entrypoint<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn skip_entrypoint<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If the container has an entrypoint, ignore it for args rather than using it to wrap them.
sourcepub fn stdin<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn stdin<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
Content to write to the command’s standard input before closing (e.g., “Hello world”).
sourcepub fn build(
&self
) -> Result<ContainerWithExecOpts<'a>, ContainerWithExecOptsBuilderError>
pub fn build( &self ) -> Result<ContainerWithExecOpts<'a>, ContainerWithExecOptsBuilderError>