pub struct ContainerWithMountedCacheOptsBuilder<'a> { /* private fields */ }Expand description
Builder for ContainerWithMountedCacheOpts.
Implementations
sourceimpl<'a> ContainerWithMountedCacheOptsBuilder<'a>
impl<'a> ContainerWithMountedCacheOptsBuilder<'a>
sourcepub fn owner<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn owner<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
A user:group to set for the mounted cache directory. Note that this changes the ownership of the specified mount along with the initial filesystem provided by source (if any). It does not have any effect if/when the cache has already been created. The user and group can either be an ID (1000:1000) or a name (foo:bar). If the group is omitted, it defaults to the same as the user.
sourcepub fn sharing<VALUE: Into<CacheSharingMode>>(
&mut self,
value: VALUE
) -> &mut Self
pub fn sharing<VALUE: Into<CacheSharingMode>>( &mut self, value: VALUE ) -> &mut Self
Sharing mode of the cache volume.
sourcepub fn source<VALUE: Into<DirectoryId>>(&mut self, value: VALUE) -> &mut Self
pub fn source<VALUE: Into<DirectoryId>>(&mut self, value: VALUE) -> &mut Self
Identifier of the directory to use as the cache volume’s root.
sourcepub fn build(
&self
) -> Result<ContainerWithMountedCacheOpts<'a>, ContainerWithMountedCacheOptsBuilderError>
pub fn build( &self ) -> Result<ContainerWithMountedCacheOpts<'a>, ContainerWithMountedCacheOptsBuilderError>