Struct dagger_sdk::DirectoryAsModuleOptsBuilder
source · pub struct DirectoryAsModuleOptsBuilder<'a> { /* private fields */ }Expand description
Builder for DirectoryAsModuleOpts.
Implementations
sourceimpl<'a> DirectoryAsModuleOptsBuilder<'a>
impl<'a> DirectoryAsModuleOptsBuilder<'a>
sourcepub fn source_subpath<VALUE: Into<&'a str>>(
&mut self,
value: VALUE
) -> &mut Self
pub fn source_subpath<VALUE: Into<&'a str>>( &mut self, value: VALUE ) -> &mut Self
An optional subpath of the directory which contains the module’s source code. This is needed when the module code is in a subdirectory but requires parent directories to be loaded in order to execute. For example, the module source code may need a go.mod, project.toml, package.json, etc. file from a parent directory. If not set, the module source code is loaded from the root of the directory.
sourcepub fn build(
&self
) -> Result<DirectoryAsModuleOpts<'a>, DirectoryAsModuleOptsBuilderError>
pub fn build( &self ) -> Result<DirectoryAsModuleOpts<'a>, DirectoryAsModuleOptsBuilderError>