EngineCachePruneOpts

Struct EngineCachePruneOpts 

pub struct EngineCachePruneOpts<'a> {
    pub max_estimated_bytes: Option<isize>,
    pub max_used_space: Option<&'a str>,
    pub min_free_space: Option<&'a str>,
    pub reserved_space: Option<&'a str>,
    pub target_estimated_bytes: Option<isize>,
    pub target_space: Option<&'a str>,
    pub use_default_policy: Option<bool>,
}

Fields

max_estimated_bytes: Option<isize>

Override the maximum structural metadata estimate in absolute bytes. Explicit values must be positive; the configured/default value is used when omitted.

max_used_space: Option<&'a str>

Override the maximum disk space to keep before pruning (e.g. “200GB” or “80%”).

min_free_space: Option<&'a str>

Override the minimum free disk space target during pruning (e.g. “20GB” or “20%”).

reserved_space: Option<&'a str>

Override the minimum disk space to retain during pruning (e.g. “500GB” or “10%”).

target_estimated_bytes: Option<isize>

Override the structural metadata estimate to target in absolute bytes. Explicit values must be positive and lower than the resolved maximum; the configured/default value is used when omitted.

target_space: Option<&'a str>

Override the target disk space to keep after pruning (e.g. “200GB” or “50%”).

use_default_policy: Option<bool>

Use enabled engine-wide default disk and structural policies. If no default disk policy is enabled, the disk stage falls back to pruning all releasable disk-cache entries. If false, explicit options select stages; with no options, all releasable disk-cache entries are pruned.