pub struct EngineCachePruneOptsBuilder<'a> { /* private fields */ }Expand description
Builder for EngineCachePruneOpts.
Implementations
Sourceimpl<'a> EngineCachePruneOptsBuilder<'a>
impl<'a> EngineCachePruneOptsBuilder<'a>
Sourcepub fn max_used_space<VALUE: Into<&'a str>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn max_used_space<VALUE: Into<&'a str>>( &mut self, value: VALUE, ) -> &mut Self
Override the maximum disk space to keep before pruning (e.g. “200GB” or “80%”).
Sourcepub fn min_free_space<VALUE: Into<&'a str>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn min_free_space<VALUE: Into<&'a str>>( &mut self, value: VALUE, ) -> &mut Self
Override the minimum free disk space target during pruning (e.g. “20GB” or “20%”).
Sourcepub fn reserved_space<VALUE: Into<&'a str>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn reserved_space<VALUE: Into<&'a str>>( &mut self, value: VALUE, ) -> &mut Self
Override the minimum disk space to retain during pruning (e.g. “500GB” or “10%”).
Sourcepub fn target_space<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn target_space<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
Override the target disk space to keep after pruning (e.g. “200GB” or “50%”).
Sourcepub fn use_default_policy<VALUE: Into<bool>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn use_default_policy<VALUE: Into<bool>>( &mut self, value: VALUE, ) -> &mut Self
Use the engine-wide default pruning policy if true, otherwise prune the whole cache of any releasable entries.
Sourcepub fn build(
&self,
) -> Result<EngineCachePruneOpts<'a>, EngineCachePruneOptsBuilderError>
pub fn build( &self, ) -> Result<EngineCachePruneOpts<'a>, EngineCachePruneOptsBuilderError>