Struct dagger_sdk::FileExportOpts
source · pub struct FileExportOpts {
pub allow_parent_dir_path: Option<bool>,
}Fields
allow_parent_dir_path: Option<bool>If allowParentDirPath is true, the path argument can be a directory path, in which case the file will be created in that directory.