Struct dagger_sdk::FileExportOptsBuilder
source · pub struct FileExportOptsBuilder { /* private fields */ }Expand description
Builder for FileExportOpts.
Implementations
sourceimpl FileExportOptsBuilder
impl FileExportOptsBuilder
sourcepub fn allow_parent_dir_path<VALUE: Into<bool>>(
&mut self,
value: VALUE
) -> &mut Self
pub fn allow_parent_dir_path<VALUE: Into<bool>>( &mut self, value: VALUE ) -> &mut Self
If allowParentDirPath is true, the path argument can be a directory path, in which case the file will be created in that directory.
sourcepub fn build(&self) -> Result<FileExportOpts, FileExportOptsBuilderError>
pub fn build(&self) -> Result<FileExportOpts, FileExportOptsBuilderError>