pub struct Generator {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl Generator
impl Generator
Sourcepub async fn completed(&self) -> Result<bool, DaggerError>
pub async fn completed(&self) -> Result<bool, DaggerError>
Whether the generator complete
Sourcepub async fn description(&self) -> Result<String, DaggerError>
pub async fn description(&self) -> Result<String, DaggerError>
Return the description of the generator
Sourcepub async fn id(&self) -> Result<GeneratorId, DaggerError>
pub async fn id(&self) -> Result<GeneratorId, DaggerError>
A unique identifier for this Generator.
Sourcepub async fn is_empty(&self) -> Result<bool, DaggerError>
pub async fn is_empty(&self) -> Result<bool, DaggerError>
Wether changeset from the generator execution is empty or not
Sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
Return the fully qualified name of the generator
Sourcepub fn original_module(&self) -> Module
pub fn original_module(&self) -> Module
The original module in which the generator has been defined