pub struct GeneratorGroup {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl GeneratorGroup
impl GeneratorGroup
Sourcepub fn changes(&self) -> Changeset
pub fn changes(&self) -> Changeset
The combined changes from the generators execution If any conflict occurs, for instance if the same file is modified by multiple generators, or if a file is both modified and deleted, an error is raised and the merge of the changesets will failed. Set ‘continueOnConflicts’ flag to force to merge the changes in a ‘last write wins’ strategy.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn changes_opts(&self, opts: GeneratorGroupChangesOpts) -> Changeset
pub fn changes_opts(&self, opts: GeneratorGroupChangesOpts) -> Changeset
The combined changes from the generators execution If any conflict occurs, for instance if the same file is modified by multiple generators, or if a file is both modified and deleted, an error is raised and the merge of the changesets will failed. Set ‘continueOnConflicts’ flag to force to merge the changes in a ‘last write wins’ strategy.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn id(&self) -> Result<GeneratorGroupId, DaggerError>
pub async fn id(&self) -> Result<GeneratorGroupId, DaggerError>
A unique identifier for this GeneratorGroup.
Sourcepub async fn is_empty(&self) -> Result<bool, DaggerError>
pub async fn is_empty(&self) -> Result<bool, DaggerError>
Whether the generated changeset is empty or not
Sourcepub fn run(&self) -> GeneratorGroup
pub fn run(&self) -> GeneratorGroup
Execute all selected generators