pub struct GitCommit {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl GitCommit
impl GitCommit
Sourcepub async fn ancestor_release_tag(&self) -> Result<Option<GitRef>, DaggerError>
pub async fn ancestor_release_tag(&self) -> Result<Option<GitRef>, DaggerError>
The latest semver release tag reachable from this commit.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn ancestor_release_tag_opts(
&self,
opts: GitCommitAncestorReleaseTagOpts,
) -> Result<Option<GitRef>, DaggerError>
pub async fn ancestor_release_tag_opts( &self, opts: GitCommitAncestorReleaseTagOpts, ) -> Result<Option<GitRef>, DaggerError>
The latest semver release tag reachable from this commit.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Git author email.
Git author name.
Git author date, in RFC3339 format.
Sourcepub async fn committed_date(&self) -> Result<String, DaggerError>
pub async fn committed_date(&self) -> Result<String, DaggerError>
Git committer date, in RFC3339 format.
Sourcepub async fn committer_email(&self) -> Result<String, DaggerError>
pub async fn committer_email(&self) -> Result<String, DaggerError>
Git committer email.
Sourcepub async fn committer_name(&self) -> Result<String, DaggerError>
pub async fn committer_name(&self) -> Result<String, DaggerError>
Git committer name.
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this GitCommit.
Sourcepub async fn message(&self) -> Result<String, DaggerError>
pub async fn message(&self) -> Result<String, DaggerError>
Full commit message.
Sourcepub async fn message_body(&self) -> Result<String, DaggerError>
pub async fn message_body(&self) -> Result<String, DaggerError>
Commit message body, excluding the headline.
Sourcepub async fn message_headline(&self) -> Result<String, DaggerError>
pub async fn message_headline(&self) -> Result<String, DaggerError>
First line of the commit message.
Sourcepub async fn parent_shas(&self) -> Result<Vec<String>, DaggerError>
pub async fn parent_shas(&self) -> Result<Vec<String>, DaggerError>
Parent commit SHAs.
Sourcepub async fn release_tag(&self) -> Result<Option<GitRef>, DaggerError>
pub async fn release_tag(&self) -> Result<Option<GitRef>, DaggerError>
The latest semver release tag that points directly at this commit.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn release_tag_opts(
&self,
opts: GitCommitReleaseTagOpts,
) -> Result<Option<GitRef>, DaggerError>
pub async fn release_tag_opts( &self, opts: GitCommitReleaseTagOpts, ) -> Result<Option<GitRef>, DaggerError>
The latest semver release tag that points directly at this commit.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn sha(&self) -> Result<String, DaggerError>
pub async fn sha(&self) -> Result<String, DaggerError>
The full commit SHA.
Sourcepub async fn short_sha(&self) -> Result<String, DaggerError>
pub async fn short_sha(&self) -> Result<String, DaggerError>
The abbreviated commit SHA.
Sourcepub fn tree(&self) -> Directory
pub fn tree(&self) -> Directory
The filesystem tree at this commit.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn tree_opts(&self, opts: GitCommitTreeOpts) -> Directory
pub fn tree_opts(&self, opts: GitCommitTreeOpts) -> Directory
The filesystem tree at this commit.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use