pub struct GitRef {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl GitRef
impl GitRef
Sourcepub fn as_workspace(&self) -> Workspace
pub fn as_workspace(&self) -> Workspace
Creates a synthetic workspace from this git ref.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn as_workspace_opts<'a>(
&self,
opts: GitRefAsWorkspaceOpts<'a>,
) -> Workspace
pub fn as_workspace_opts<'a>( &self, opts: GitRefAsWorkspaceOpts<'a>, ) -> Workspace
Creates a synthetic workspace from this git ref.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn commit(&self) -> Result<String, DaggerError>
pub async fn commit(&self) -> Result<String, DaggerError>
The resolved commit id at this ref.
Sourcepub async fn commit_sha(&self) -> Result<String, DaggerError>
pub async fn commit_sha(&self) -> Result<String, DaggerError>
The resolved commit SHA at this ref.
Sourcepub fn common_ancestor(&self, other: impl IntoID<Id>) -> GitRef
pub fn common_ancestor(&self, other: impl IntoID<Id>) -> GitRef
Find the best common ancestor between this ref and another ref.
Arguments
other- The other ref to compare against.
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this GitRef.
Sourcepub async fn log(&self) -> Result<Vec<GitCommit>, DaggerError>
pub async fn log(&self) -> Result<Vec<GitCommit>, DaggerError>
Commits reachable from this ref, newest first, starting with the commit this ref resolves to.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn log_opts<'a>(
&self,
opts: GitRefLogOpts<'a>,
) -> Result<Vec<GitCommit>, DaggerError>
pub async fn log_opts<'a>( &self, opts: GitRefLogOpts<'a>, ) -> Result<Vec<GitCommit>, DaggerError>
Commits reachable from this ref, newest first, starting with the commit this ref resolves to.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
The resolved name of this ref.
Sourcepub async fn ref(&self) -> Result<String, DaggerError>
pub async fn ref(&self) -> Result<String, DaggerError>
The resolved ref name at this ref.
Sourcepub fn target_commit(&self) -> GitCommit
pub fn target_commit(&self) -> GitCommit
The commit this ref resolves to.
Sourcepub fn tree(&self) -> Directory
pub fn tree(&self) -> Directory
The filesystem tree at this ref.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn tree_opts(&self, opts: GitRefTreeOpts) -> Directory
pub fn tree_opts(&self, opts: GitRefTreeOpts) -> Directory
The filesystem tree at this ref.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use