pub struct GitRepository {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl GitRepository
impl GitRepository
Sourcepub fn as_workspace(&self) -> Workspace
pub fn as_workspace(&self) -> Workspace
Creates a synthetic workspace from this git repository.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn as_workspace_opts<'a>(
&self,
opts: GitRepositoryAsWorkspaceOpts<'a>,
) -> Workspace
pub fn as_workspace_opts<'a>( &self, opts: GitRepositoryAsWorkspaceOpts<'a>, ) -> Workspace
Creates a synthetic workspace from this git repository.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn branches(&self) -> Result<Vec<String>, DaggerError>
pub async fn branches(&self) -> Result<Vec<String>, DaggerError>
branches that match any of the given glob patterns.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub async fn branches_opts<'a>(
&self,
opts: GitRepositoryBranchesOpts<'a>,
) -> Result<Vec<String>, DaggerError>
pub async fn branches_opts<'a>( &self, opts: GitRepositoryBranchesOpts<'a>, ) -> Result<Vec<String>, DaggerError>
branches that match any of the given glob patterns.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn bundle(&self, refs: Vec<impl Into<String>>) -> GitBundle
pub fn bundle(&self, refs: Vec<impl Into<String>>) -> GitBundle
Pack the given refs and the objects needed to reconstruct them into a Git bundle.
Arguments
refs- Refs to advertise in the bundle. At least one named ref is required.opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn bundle_opts(
&self,
refs: Vec<impl Into<String>>,
opts: GitRepositoryBundleOpts,
) -> GitBundle
pub fn bundle_opts( &self, refs: Vec<impl Into<String>>, opts: GitRepositoryBundleOpts, ) -> GitBundle
Pack the given refs and the objects needed to reconstruct them into a Git bundle.
Arguments
refs- Refs to advertise in the bundle. At least one named ref is required.opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn commit(&self, id: impl Into<String>) -> GitCommit
pub fn commit(&self, id: impl Into<String>) -> GitCommit
Returns details of a commit.
Arguments
id- Identifier of the commit (e.g., “b6315d8f2810962c601af73f86831f6866ea798b”).
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this GitRepository.
Sourcepub fn latest(&self) -> GitRef
pub fn latest(&self) -> GitRef
Return the latest stable release tag, falling back to HEAD when no release exists. Release selection accepts an optional “v” prefix, incomplete versions, and zero-padded numeric components. This operation is pinned.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn latest_opts<'a>(&self, opts: GitRepositoryLatestOpts<'a>) -> GitRef
pub fn latest_opts<'a>(&self, opts: GitRepositoryLatestOpts<'a>) -> GitRef
Return the latest stable release tag, falling back to HEAD when no release exists. Release selection accepts an optional “v” prefix, incomplete versions, and zero-padded numeric components. This operation is pinned.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn ref(&self, name: impl Into<String>) -> GitRef
pub fn ref(&self, name: impl Into<String>) -> GitRef
Returns details of a ref.
Arguments
name- Ref’s name (can be a commit identifier, a tag name, a branch name, or a fully-qualified ref).
tags that match any of the given glob patterns.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
tags that match any of the given glob patterns.
Arguments
opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn uncommitted(&self) -> Changeset
pub fn uncommitted(&self) -> Changeset
Returns the changeset of uncommitted changes in the git repository.
Sourcepub async fn url(&self) -> Result<String, DaggerError>
pub async fn url(&self) -> Result<String, DaggerError>
The URL of the git repository.
Sourcepub fn with_bundle(&self, bundle: impl IntoID<Id>) -> GitRepository
pub fn with_bundle(&self, bundle: impl IntoID<Id>) -> GitRepository
Import a Git bundle after fetching and verifying all of its prerequisites.
Arguments
bundle- The Git bundle to import.opt- optional argument, see inner type for documentation, use_opts to use
Sourcepub fn with_bundle_opts<'a>(
&self,
bundle: impl IntoID<Id>,
opts: GitRepositoryWithBundleOpts<'a>,
) -> GitRepository
pub fn with_bundle_opts<'a>( &self, bundle: impl IntoID<Id>, opts: GitRepositoryWithBundleOpts<'a>, ) -> GitRepository
Import a Git bundle after fetching and verifying all of its prerequisites.
Arguments
bundle- The Git bundle to import.opt- optional argument, see inner type for documentation, use_opts to use