pub struct Llm {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl Llm
impl Llm
Sourcepub fn cache_volume(&self) -> CacheVolume
pub fn cache_volume(&self) -> CacheVolume
Retrieve a the current value in the LLM environment, of type CacheVolume
Sourcepub fn container(&self) -> Container
pub fn container(&self) -> Container
Retrieve a the current value in the LLM environment, of type Container
Sourcepub fn current_module(&self) -> CurrentModule
pub fn current_module(&self) -> CurrentModule
Retrieve a the current value in the LLM environment, of type CurrentModule
Sourcepub async fn current_type(&self) -> Result<String, DaggerError>
pub async fn current_type(&self) -> Result<String, DaggerError>
returns the type of the current state
Sourcepub fn directory(&self) -> Directory
pub fn directory(&self) -> Directory
Retrieve a the current value in the LLM environment, of type Directory
Sourcepub fn enum_type_def(&self) -> EnumTypeDef
pub fn enum_type_def(&self) -> EnumTypeDef
Retrieve a the current value in the LLM environment, of type EnumTypeDef
Sourcepub fn enum_value_type_def(&self) -> EnumValueTypeDef
pub fn enum_value_type_def(&self) -> EnumValueTypeDef
Retrieve a the current value in the LLM environment, of type EnumValueTypeDef
Sourcepub fn error(&self) -> Error
pub fn error(&self) -> Error
Retrieve a the current value in the LLM environment, of type Error
Sourcepub fn error_value(&self) -> ErrorValue
pub fn error_value(&self) -> ErrorValue
Retrieve a the current value in the LLM environment, of type ErrorValue
Sourcepub fn field_type_def(&self) -> FieldTypeDef
pub fn field_type_def(&self) -> FieldTypeDef
Retrieve a the current value in the LLM environment, of type FieldTypeDef
Sourcepub fn function(&self) -> Function
pub fn function(&self) -> Function
Retrieve a the current value in the LLM environment, of type Function
Sourcepub fn function_arg(&self) -> FunctionArg
pub fn function_arg(&self) -> FunctionArg
Retrieve a the current value in the LLM environment, of type FunctionArg
Sourcepub fn function_call(&self) -> FunctionCall
pub fn function_call(&self) -> FunctionCall
Retrieve a the current value in the LLM environment, of type FunctionCall
Sourcepub fn function_call_arg_value(&self) -> FunctionCallArgValue
pub fn function_call_arg_value(&self) -> FunctionCallArgValue
Retrieve a the current value in the LLM environment, of type FunctionCallArgValue
Sourcepub fn generated_code(&self) -> GeneratedCode
pub fn generated_code(&self) -> GeneratedCode
Retrieve a the current value in the LLM environment, of type GeneratedCode
Sourcepub fn get_cache_volume(&self, name: impl Into<String>) -> CacheVolume
pub fn get_cache_volume(&self, name: impl Into<String>) -> CacheVolume
Retrieve a variable in the llm environment, of type CacheVolume
Arguments
name- The name of the variable
Sourcepub fn get_container(&self, name: impl Into<String>) -> Container
pub fn get_container(&self, name: impl Into<String>) -> Container
Retrieve a variable in the llm environment, of type Container
Arguments
name- The name of the variable
Sourcepub fn get_current_module(&self, name: impl Into<String>) -> CurrentModule
pub fn get_current_module(&self, name: impl Into<String>) -> CurrentModule
Retrieve a variable in the llm environment, of type CurrentModule
Arguments
name- The name of the variable
Sourcepub fn get_directory(&self, name: impl Into<String>) -> Directory
pub fn get_directory(&self, name: impl Into<String>) -> Directory
Retrieve a variable in the llm environment, of type Directory
Arguments
name- The name of the variable
Sourcepub fn get_enum_type_def(&self, name: impl Into<String>) -> EnumTypeDef
pub fn get_enum_type_def(&self, name: impl Into<String>) -> EnumTypeDef
Retrieve a variable in the llm environment, of type EnumTypeDef
Arguments
name- The name of the variable
Sourcepub fn get_enum_value_type_def(
&self,
name: impl Into<String>,
) -> EnumValueTypeDef
pub fn get_enum_value_type_def( &self, name: impl Into<String>, ) -> EnumValueTypeDef
Retrieve a variable in the llm environment, of type EnumValueTypeDef
Arguments
name- The name of the variable
Sourcepub fn get_error(&self, name: impl Into<String>) -> Error
pub fn get_error(&self, name: impl Into<String>) -> Error
Retrieve a variable in the llm environment, of type Error
Arguments
name- The name of the variable
Sourcepub fn get_error_value(&self, name: impl Into<String>) -> ErrorValue
pub fn get_error_value(&self, name: impl Into<String>) -> ErrorValue
Retrieve a variable in the llm environment, of type ErrorValue
Arguments
name- The name of the variable
Sourcepub fn get_field_type_def(&self, name: impl Into<String>) -> FieldTypeDef
pub fn get_field_type_def(&self, name: impl Into<String>) -> FieldTypeDef
Retrieve a variable in the llm environment, of type FieldTypeDef
Arguments
name- The name of the variable
Sourcepub fn get_function(&self, name: impl Into<String>) -> Function
pub fn get_function(&self, name: impl Into<String>) -> Function
Retrieve a variable in the llm environment, of type Function
Arguments
name- The name of the variable
Sourcepub fn get_function_arg(&self, name: impl Into<String>) -> FunctionArg
pub fn get_function_arg(&self, name: impl Into<String>) -> FunctionArg
Retrieve a variable in the llm environment, of type FunctionArg
Arguments
name- The name of the variable
Sourcepub fn get_function_call(&self, name: impl Into<String>) -> FunctionCall
pub fn get_function_call(&self, name: impl Into<String>) -> FunctionCall
Retrieve a variable in the llm environment, of type FunctionCall
Arguments
name- The name of the variable
Sourcepub fn get_function_call_arg_value(
&self,
name: impl Into<String>,
) -> FunctionCallArgValue
pub fn get_function_call_arg_value( &self, name: impl Into<String>, ) -> FunctionCallArgValue
Retrieve a variable in the llm environment, of type FunctionCallArgValue
Arguments
name- The name of the variable
Sourcepub fn get_generated_code(&self, name: impl Into<String>) -> GeneratedCode
pub fn get_generated_code(&self, name: impl Into<String>) -> GeneratedCode
Retrieve a variable in the llm environment, of type GeneratedCode
Arguments
name- The name of the variable
Sourcepub fn get_git_ref(&self, name: impl Into<String>) -> GitRef
pub fn get_git_ref(&self, name: impl Into<String>) -> GitRef
Retrieve a variable in the llm environment, of type GitRef
Arguments
name- The name of the variable
Sourcepub fn get_git_repository(&self, name: impl Into<String>) -> GitRepository
pub fn get_git_repository(&self, name: impl Into<String>) -> GitRepository
Retrieve a variable in the llm environment, of type GitRepository
Arguments
name- The name of the variable
Sourcepub fn get_input_type_def(&self, name: impl Into<String>) -> InputTypeDef
pub fn get_input_type_def(&self, name: impl Into<String>) -> InputTypeDef
Retrieve a variable in the llm environment, of type InputTypeDef
Arguments
name- The name of the variable
Sourcepub fn get_interface_type_def(
&self,
name: impl Into<String>,
) -> InterfaceTypeDef
pub fn get_interface_type_def( &self, name: impl Into<String>, ) -> InterfaceTypeDef
Retrieve a variable in the llm environment, of type InterfaceTypeDef
Arguments
name- The name of the variable
Sourcepub fn get_list_type_def(&self, name: impl Into<String>) -> ListTypeDef
pub fn get_list_type_def(&self, name: impl Into<String>) -> ListTypeDef
Retrieve a variable in the llm environment, of type ListTypeDef
Arguments
name- The name of the variable
Sourcepub fn get_module(&self, name: impl Into<String>) -> Module
pub fn get_module(&self, name: impl Into<String>) -> Module
Retrieve a variable in the llm environment, of type Module
Arguments
name- The name of the variable
Sourcepub fn get_module_config_client(
&self,
name: impl Into<String>,
) -> ModuleConfigClient
pub fn get_module_config_client( &self, name: impl Into<String>, ) -> ModuleConfigClient
Retrieve a variable in the llm environment, of type ModuleConfigClient
Arguments
name- The name of the variable
Sourcepub fn get_module_source(&self, name: impl Into<String>) -> ModuleSource
pub fn get_module_source(&self, name: impl Into<String>) -> ModuleSource
Retrieve a variable in the llm environment, of type ModuleSource
Arguments
name- The name of the variable
Sourcepub fn get_object_type_def(&self, name: impl Into<String>) -> ObjectTypeDef
pub fn get_object_type_def(&self, name: impl Into<String>) -> ObjectTypeDef
Retrieve a variable in the llm environment, of type ObjectTypeDef
Arguments
name- The name of the variable
Sourcepub fn get_sdk_config(&self, name: impl Into<String>) -> SdkConfig
pub fn get_sdk_config(&self, name: impl Into<String>) -> SdkConfig
Retrieve a variable in the llm environment, of type SDKConfig
Arguments
name- The name of the variable
Sourcepub fn get_scalar_type_def(&self, name: impl Into<String>) -> ScalarTypeDef
pub fn get_scalar_type_def(&self, name: impl Into<String>) -> ScalarTypeDef
Retrieve a variable in the llm environment, of type ScalarTypeDef
Arguments
name- The name of the variable
Sourcepub fn get_secret(&self, name: impl Into<String>) -> Secret
pub fn get_secret(&self, name: impl Into<String>) -> Secret
Retrieve a variable in the llm environment, of type Secret
Arguments
name- The name of the variable
Sourcepub fn get_service(&self, name: impl Into<String>) -> Service
pub fn get_service(&self, name: impl Into<String>) -> Service
Retrieve a variable in the llm environment, of type Service
Arguments
name- The name of the variable
Sourcepub fn get_socket(&self, name: impl Into<String>) -> Socket
pub fn get_socket(&self, name: impl Into<String>) -> Socket
Retrieve a variable in the llm environment, of type Socket
Arguments
name- The name of the variable
Sourcepub fn get_source_map(&self, name: impl Into<String>) -> SourceMap
pub fn get_source_map(&self, name: impl Into<String>) -> SourceMap
Retrieve a variable in the llm environment, of type SourceMap
Arguments
name- The name of the variable
Sourcepub async fn get_string(
&self,
name: impl Into<String>,
) -> Result<String, DaggerError>
pub async fn get_string( &self, name: impl Into<String>, ) -> Result<String, DaggerError>
Sourcepub fn get_terminal(&self, name: impl Into<String>) -> Terminal
pub fn get_terminal(&self, name: impl Into<String>) -> Terminal
Retrieve a variable in the llm environment, of type Terminal
Arguments
name- The name of the variable
Sourcepub fn get_type_def(&self, name: impl Into<String>) -> TypeDef
pub fn get_type_def(&self, name: impl Into<String>) -> TypeDef
Retrieve a variable in the llm environment, of type TypeDef
Arguments
name- The name of the variable
Sourcepub fn git_ref(&self) -> GitRef
pub fn git_ref(&self) -> GitRef
Retrieve a the current value in the LLM environment, of type GitRef
Sourcepub fn git_repository(&self) -> GitRepository
pub fn git_repository(&self) -> GitRepository
Retrieve a the current value in the LLM environment, of type GitRepository
Sourcepub async fn history_json(&self) -> Result<String, DaggerError>
pub async fn history_json(&self) -> Result<String, DaggerError>
return the raw llm message history as json
Sourcepub async fn id(&self) -> Result<Llmid, DaggerError>
pub async fn id(&self) -> Result<Llmid, DaggerError>
A unique identifier for this LLM.
Sourcepub fn input_type_def(&self) -> InputTypeDef
pub fn input_type_def(&self) -> InputTypeDef
Retrieve a the current value in the LLM environment, of type InputTypeDef
Sourcepub fn interface_type_def(&self) -> InterfaceTypeDef
pub fn interface_type_def(&self) -> InterfaceTypeDef
Retrieve a the current value in the LLM environment, of type InterfaceTypeDef
Sourcepub async fn last_reply(&self) -> Result<String, DaggerError>
pub async fn last_reply(&self) -> Result<String, DaggerError>
return the last llm reply from the history
Sourcepub fn list_type_def(&self) -> ListTypeDef
pub fn list_type_def(&self) -> ListTypeDef
Retrieve a the current value in the LLM environment, of type ListTypeDef
Sourcepub async fn model(&self) -> Result<String, DaggerError>
pub async fn model(&self) -> Result<String, DaggerError>
return the model used by the llm
Sourcepub fn module(&self) -> Module
pub fn module(&self) -> Module
Retrieve a the current value in the LLM environment, of type Module
Sourcepub fn module_config_client(&self) -> ModuleConfigClient
pub fn module_config_client(&self) -> ModuleConfigClient
Retrieve a the current value in the LLM environment, of type ModuleConfigClient
Sourcepub fn module_source(&self) -> ModuleSource
pub fn module_source(&self) -> ModuleSource
Retrieve a the current value in the LLM environment, of type ModuleSource
Sourcepub fn object_type_def(&self) -> ObjectTypeDef
pub fn object_type_def(&self) -> ObjectTypeDef
Retrieve a the current value in the LLM environment, of type ObjectTypeDef
Sourcepub async fn provider(&self) -> Result<String, DaggerError>
pub async fn provider(&self) -> Result<String, DaggerError>
return the provider used by the llm
Sourcepub fn scalar_type_def(&self) -> ScalarTypeDef
pub fn scalar_type_def(&self) -> ScalarTypeDef
Retrieve a the current value in the LLM environment, of type ScalarTypeDef
Sourcepub fn sdkconfig(&self) -> SdkConfig
pub fn sdkconfig(&self) -> SdkConfig
Retrieve a the current value in the LLM environment, of type SDKConfig
Sourcepub fn secret(&self) -> Secret
pub fn secret(&self) -> Secret
Retrieve a the current value in the LLM environment, of type Secret
Sourcepub fn service(&self) -> Service
pub fn service(&self) -> Service
Retrieve a the current value in the LLM environment, of type Service
Sourcepub fn set_cache_volume(
&self,
name: impl Into<String>,
value: impl IntoID<CacheVolumeId>,
) -> Llm
pub fn set_cache_volume( &self, name: impl Into<String>, value: impl IntoID<CacheVolumeId>, ) -> Llm
Set a variable of type CacheVolume in the llm environment
Arguments
name- The name of the variablevalue- The CacheVolume value to assign to the variable
Sourcepub fn set_container(
&self,
name: impl Into<String>,
value: impl IntoID<ContainerId>,
) -> Llm
pub fn set_container( &self, name: impl Into<String>, value: impl IntoID<ContainerId>, ) -> Llm
Set a variable of type Container in the llm environment
Arguments
name- The name of the variablevalue- The Container value to assign to the variable
Sourcepub fn set_current_module(
&self,
name: impl Into<String>,
value: impl IntoID<CurrentModuleId>,
) -> Llm
pub fn set_current_module( &self, name: impl Into<String>, value: impl IntoID<CurrentModuleId>, ) -> Llm
Set a variable of type CurrentModule in the llm environment
Arguments
name- The name of the variablevalue- The CurrentModule value to assign to the variable
Sourcepub fn set_directory(
&self,
name: impl Into<String>,
value: impl IntoID<DirectoryId>,
) -> Llm
pub fn set_directory( &self, name: impl Into<String>, value: impl IntoID<DirectoryId>, ) -> Llm
Set a variable of type Directory in the llm environment
Arguments
name- The name of the variablevalue- The Directory value to assign to the variable
Sourcepub fn set_enum_type_def(
&self,
name: impl Into<String>,
value: impl IntoID<EnumTypeDefId>,
) -> Llm
pub fn set_enum_type_def( &self, name: impl Into<String>, value: impl IntoID<EnumTypeDefId>, ) -> Llm
Set a variable of type EnumTypeDef in the llm environment
Arguments
name- The name of the variablevalue- The EnumTypeDef value to assign to the variable
Sourcepub fn set_enum_value_type_def(
&self,
name: impl Into<String>,
value: impl IntoID<EnumValueTypeDefId>,
) -> Llm
pub fn set_enum_value_type_def( &self, name: impl Into<String>, value: impl IntoID<EnumValueTypeDefId>, ) -> Llm
Set a variable of type EnumValueTypeDef in the llm environment
Arguments
name- The name of the variablevalue- The EnumValueTypeDef value to assign to the variable
Sourcepub fn set_error(
&self,
name: impl Into<String>,
value: impl IntoID<ErrorId>,
) -> Llm
pub fn set_error( &self, name: impl Into<String>, value: impl IntoID<ErrorId>, ) -> Llm
Set a variable of type Error in the llm environment
Arguments
name- The name of the variablevalue- The Error value to assign to the variable
Sourcepub fn set_error_value(
&self,
name: impl Into<String>,
value: impl IntoID<ErrorValueId>,
) -> Llm
pub fn set_error_value( &self, name: impl Into<String>, value: impl IntoID<ErrorValueId>, ) -> Llm
Set a variable of type ErrorValue in the llm environment
Arguments
name- The name of the variablevalue- The ErrorValue value to assign to the variable
Sourcepub fn set_field_type_def(
&self,
name: impl Into<String>,
value: impl IntoID<FieldTypeDefId>,
) -> Llm
pub fn set_field_type_def( &self, name: impl Into<String>, value: impl IntoID<FieldTypeDefId>, ) -> Llm
Set a variable of type FieldTypeDef in the llm environment
Arguments
name- The name of the variablevalue- The FieldTypeDef value to assign to the variable
Sourcepub fn set_file(
&self,
name: impl Into<String>,
value: impl IntoID<FileId>,
) -> Llm
pub fn set_file( &self, name: impl Into<String>, value: impl IntoID<FileId>, ) -> Llm
Set a variable of type File in the llm environment
Arguments
name- The name of the variablevalue- The File value to assign to the variable
Sourcepub fn set_function(
&self,
name: impl Into<String>,
value: impl IntoID<FunctionId>,
) -> Llm
pub fn set_function( &self, name: impl Into<String>, value: impl IntoID<FunctionId>, ) -> Llm
Set a variable of type Function in the llm environment
Arguments
name- The name of the variablevalue- The Function value to assign to the variable
Sourcepub fn set_function_arg(
&self,
name: impl Into<String>,
value: impl IntoID<FunctionArgId>,
) -> Llm
pub fn set_function_arg( &self, name: impl Into<String>, value: impl IntoID<FunctionArgId>, ) -> Llm
Set a variable of type FunctionArg in the llm environment
Arguments
name- The name of the variablevalue- The FunctionArg value to assign to the variable
Sourcepub fn set_function_call(
&self,
name: impl Into<String>,
value: impl IntoID<FunctionCallId>,
) -> Llm
pub fn set_function_call( &self, name: impl Into<String>, value: impl IntoID<FunctionCallId>, ) -> Llm
Set a variable of type FunctionCall in the llm environment
Arguments
name- The name of the variablevalue- The FunctionCall value to assign to the variable
Sourcepub fn set_function_call_arg_value(
&self,
name: impl Into<String>,
value: impl IntoID<FunctionCallArgValueId>,
) -> Llm
pub fn set_function_call_arg_value( &self, name: impl Into<String>, value: impl IntoID<FunctionCallArgValueId>, ) -> Llm
Set a variable of type FunctionCallArgValue in the llm environment
Arguments
name- The name of the variablevalue- The FunctionCallArgValue value to assign to the variable
Sourcepub fn set_generated_code(
&self,
name: impl Into<String>,
value: impl IntoID<GeneratedCodeId>,
) -> Llm
pub fn set_generated_code( &self, name: impl Into<String>, value: impl IntoID<GeneratedCodeId>, ) -> Llm
Set a variable of type GeneratedCode in the llm environment
Arguments
name- The name of the variablevalue- The GeneratedCode value to assign to the variable
Sourcepub fn set_git_ref(
&self,
name: impl Into<String>,
value: impl IntoID<GitRefId>,
) -> Llm
pub fn set_git_ref( &self, name: impl Into<String>, value: impl IntoID<GitRefId>, ) -> Llm
Set a variable of type GitRef in the llm environment
Arguments
name- The name of the variablevalue- The GitRef value to assign to the variable
Sourcepub fn set_git_repository(
&self,
name: impl Into<String>,
value: impl IntoID<GitRepositoryId>,
) -> Llm
pub fn set_git_repository( &self, name: impl Into<String>, value: impl IntoID<GitRepositoryId>, ) -> Llm
Set a variable of type GitRepository in the llm environment
Arguments
name- The name of the variablevalue- The GitRepository value to assign to the variable
Sourcepub fn set_input_type_def(
&self,
name: impl Into<String>,
value: impl IntoID<InputTypeDefId>,
) -> Llm
pub fn set_input_type_def( &self, name: impl Into<String>, value: impl IntoID<InputTypeDefId>, ) -> Llm
Set a variable of type InputTypeDef in the llm environment
Arguments
name- The name of the variablevalue- The InputTypeDef value to assign to the variable
Sourcepub fn set_interface_type_def(
&self,
name: impl Into<String>,
value: impl IntoID<InterfaceTypeDefId>,
) -> Llm
pub fn set_interface_type_def( &self, name: impl Into<String>, value: impl IntoID<InterfaceTypeDefId>, ) -> Llm
Set a variable of type InterfaceTypeDef in the llm environment
Arguments
name- The name of the variablevalue- The InterfaceTypeDef value to assign to the variable
Sourcepub fn set_llm(&self, name: impl Into<String>, value: impl IntoID<Llmid>) -> Llm
pub fn set_llm(&self, name: impl Into<String>, value: impl IntoID<Llmid>) -> Llm
Set a variable of type LLM in the llm environment
Arguments
name- The name of the variablevalue- The LLM value to assign to the variable
Sourcepub fn set_list_type_def(
&self,
name: impl Into<String>,
value: impl IntoID<ListTypeDefId>,
) -> Llm
pub fn set_list_type_def( &self, name: impl Into<String>, value: impl IntoID<ListTypeDefId>, ) -> Llm
Set a variable of type ListTypeDef in the llm environment
Arguments
name- The name of the variablevalue- The ListTypeDef value to assign to the variable
Sourcepub fn set_module(
&self,
name: impl Into<String>,
value: impl IntoID<ModuleId>,
) -> Llm
pub fn set_module( &self, name: impl Into<String>, value: impl IntoID<ModuleId>, ) -> Llm
Set a variable of type Module in the llm environment
Arguments
name- The name of the variablevalue- The Module value to assign to the variable
Sourcepub fn set_module_config_client(
&self,
name: impl Into<String>,
value: impl IntoID<ModuleConfigClientId>,
) -> Llm
pub fn set_module_config_client( &self, name: impl Into<String>, value: impl IntoID<ModuleConfigClientId>, ) -> Llm
Set a variable of type ModuleConfigClient in the llm environment
Arguments
name- The name of the variablevalue- The ModuleConfigClient value to assign to the variable
Sourcepub fn set_module_source(
&self,
name: impl Into<String>,
value: impl IntoID<ModuleSourceId>,
) -> Llm
pub fn set_module_source( &self, name: impl Into<String>, value: impl IntoID<ModuleSourceId>, ) -> Llm
Set a variable of type ModuleSource in the llm environment
Arguments
name- The name of the variablevalue- The ModuleSource value to assign to the variable
Sourcepub fn set_object_type_def(
&self,
name: impl Into<String>,
value: impl IntoID<ObjectTypeDefId>,
) -> Llm
pub fn set_object_type_def( &self, name: impl Into<String>, value: impl IntoID<ObjectTypeDefId>, ) -> Llm
Set a variable of type ObjectTypeDef in the llm environment
Arguments
name- The name of the variablevalue- The ObjectTypeDef value to assign to the variable
Sourcepub fn set_sdk_config(
&self,
name: impl Into<String>,
value: impl IntoID<SdkConfigId>,
) -> Llm
pub fn set_sdk_config( &self, name: impl Into<String>, value: impl IntoID<SdkConfigId>, ) -> Llm
Set a variable of type SDKConfig in the llm environment
Arguments
name- The name of the variablevalue- The SDKConfig value to assign to the variable
Sourcepub fn set_scalar_type_def(
&self,
name: impl Into<String>,
value: impl IntoID<ScalarTypeDefId>,
) -> Llm
pub fn set_scalar_type_def( &self, name: impl Into<String>, value: impl IntoID<ScalarTypeDefId>, ) -> Llm
Set a variable of type ScalarTypeDef in the llm environment
Arguments
name- The name of the variablevalue- The ScalarTypeDef value to assign to the variable
Sourcepub fn set_secret(
&self,
name: impl Into<String>,
value: impl IntoID<SecretId>,
) -> Llm
pub fn set_secret( &self, name: impl Into<String>, value: impl IntoID<SecretId>, ) -> Llm
Set a variable of type Secret in the llm environment
Arguments
name- The name of the variablevalue- The Secret value to assign to the variable
Sourcepub fn set_service(
&self,
name: impl Into<String>,
value: impl IntoID<ServiceId>,
) -> Llm
pub fn set_service( &self, name: impl Into<String>, value: impl IntoID<ServiceId>, ) -> Llm
Set a variable of type Service in the llm environment
Arguments
name- The name of the variablevalue- The Service value to assign to the variable
Sourcepub fn set_socket(
&self,
name: impl Into<String>,
value: impl IntoID<SocketId>,
) -> Llm
pub fn set_socket( &self, name: impl Into<String>, value: impl IntoID<SocketId>, ) -> Llm
Set a variable of type Socket in the llm environment
Arguments
name- The name of the variablevalue- The Socket value to assign to the variable
Sourcepub fn set_source_map(
&self,
name: impl Into<String>,
value: impl IntoID<SourceMapId>,
) -> Llm
pub fn set_source_map( &self, name: impl Into<String>, value: impl IntoID<SourceMapId>, ) -> Llm
Set a variable of type SourceMap in the llm environment
Arguments
name- The name of the variablevalue- The SourceMap value to assign to the variable
Sourcepub fn set_string(
&self,
name: impl Into<String>,
value: impl Into<String>,
) -> Llm
pub fn set_string( &self, name: impl Into<String>, value: impl Into<String>, ) -> Llm
Add a string variable to the LLM’s environment
Arguments
name- The variable namevalue- The variable value
Sourcepub fn set_terminal(
&self,
name: impl Into<String>,
value: impl IntoID<TerminalId>,
) -> Llm
pub fn set_terminal( &self, name: impl Into<String>, value: impl IntoID<TerminalId>, ) -> Llm
Set a variable of type Terminal in the llm environment
Arguments
name- The name of the variablevalue- The Terminal value to assign to the variable
Sourcepub fn set_type_def(
&self,
name: impl Into<String>,
value: impl IntoID<TypeDefId>,
) -> Llm
pub fn set_type_def( &self, name: impl Into<String>, value: impl IntoID<TypeDefId>, ) -> Llm
Set a variable of type TypeDef in the llm environment
Arguments
name- The name of the variablevalue- The TypeDef value to assign to the variable
Sourcepub fn socket(&self) -> Socket
pub fn socket(&self) -> Socket
Retrieve a the current value in the LLM environment, of type Socket
Sourcepub fn source_map(&self) -> SourceMap
pub fn source_map(&self) -> SourceMap
Retrieve a the current value in the LLM environment, of type SourceMap
Sourcepub async fn sync(&self) -> Result<Llmid, DaggerError>
pub async fn sync(&self) -> Result<Llmid, DaggerError>
synchronize LLM state
Sourcepub fn terminal(&self) -> Terminal
pub fn terminal(&self) -> Terminal
Retrieve a the current value in the LLM environment, of type Terminal
Sourcepub async fn tools(&self) -> Result<String, DaggerError>
pub async fn tools(&self) -> Result<String, DaggerError>
print documentation for available tools
Sourcepub fn type_def(&self) -> TypeDef
pub fn type_def(&self) -> TypeDef
Retrieve a the current value in the LLM environment, of type TypeDef
Sourcepub fn variables(&self) -> Vec<LlmVariable>
pub fn variables(&self) -> Vec<LlmVariable>
list variables in the LLM environment
Sourcepub fn with_cache_volume(&self, value: impl IntoID<CacheVolumeId>) -> Llm
pub fn with_cache_volume(&self, value: impl IntoID<CacheVolumeId>) -> Llm
Set a variable of type CacheVolume in the llm environment
Arguments
value- The CacheVolume value to assign to the variable
Sourcepub fn with_container(&self, value: impl IntoID<ContainerId>) -> Llm
pub fn with_container(&self, value: impl IntoID<ContainerId>) -> Llm
Set a variable of type Container in the llm environment
Arguments
value- The Container value to assign to the variable
Sourcepub fn with_current_module(&self, value: impl IntoID<CurrentModuleId>) -> Llm
pub fn with_current_module(&self, value: impl IntoID<CurrentModuleId>) -> Llm
Set a variable of type CurrentModule in the llm environment
Arguments
value- The CurrentModule value to assign to the variable
Sourcepub fn with_directory(&self, value: impl IntoID<DirectoryId>) -> Llm
pub fn with_directory(&self, value: impl IntoID<DirectoryId>) -> Llm
Set a variable of type Directory in the llm environment
Arguments
value- The Directory value to assign to the variable
Sourcepub fn with_enum_type_def(&self, value: impl IntoID<EnumTypeDefId>) -> Llm
pub fn with_enum_type_def(&self, value: impl IntoID<EnumTypeDefId>) -> Llm
Set a variable of type EnumTypeDef in the llm environment
Arguments
value- The EnumTypeDef value to assign to the variable
Sourcepub fn with_enum_value_type_def(
&self,
value: impl IntoID<EnumValueTypeDefId>,
) -> Llm
pub fn with_enum_value_type_def( &self, value: impl IntoID<EnumValueTypeDefId>, ) -> Llm
Set a variable of type EnumValueTypeDef in the llm environment
Arguments
value- The EnumValueTypeDef value to assign to the variable
Sourcepub fn with_error(&self, value: impl IntoID<ErrorId>) -> Llm
pub fn with_error(&self, value: impl IntoID<ErrorId>) -> Llm
Set a variable of type Error in the llm environment
Arguments
value- The Error value to assign to the variable
Sourcepub fn with_error_value(&self, value: impl IntoID<ErrorValueId>) -> Llm
pub fn with_error_value(&self, value: impl IntoID<ErrorValueId>) -> Llm
Set a variable of type ErrorValue in the llm environment
Arguments
value- The ErrorValue value to assign to the variable
Sourcepub fn with_field_type_def(&self, value: impl IntoID<FieldTypeDefId>) -> Llm
pub fn with_field_type_def(&self, value: impl IntoID<FieldTypeDefId>) -> Llm
Set a variable of type FieldTypeDef in the llm environment
Arguments
value- The FieldTypeDef value to assign to the variable
Sourcepub fn with_file(&self, value: impl IntoID<FileId>) -> Llm
pub fn with_file(&self, value: impl IntoID<FileId>) -> Llm
Set a variable of type File in the llm environment
Arguments
value- The File value to assign to the variable
Sourcepub fn with_function(&self, value: impl IntoID<FunctionId>) -> Llm
pub fn with_function(&self, value: impl IntoID<FunctionId>) -> Llm
Set a variable of type Function in the llm environment
Arguments
value- The Function value to assign to the variable
Sourcepub fn with_function_arg(&self, value: impl IntoID<FunctionArgId>) -> Llm
pub fn with_function_arg(&self, value: impl IntoID<FunctionArgId>) -> Llm
Set a variable of type FunctionArg in the llm environment
Arguments
value- The FunctionArg value to assign to the variable
Sourcepub fn with_function_call(&self, value: impl IntoID<FunctionCallId>) -> Llm
pub fn with_function_call(&self, value: impl IntoID<FunctionCallId>) -> Llm
Set a variable of type FunctionCall in the llm environment
Arguments
value- The FunctionCall value to assign to the variable
Sourcepub fn with_function_call_arg_value(
&self,
value: impl IntoID<FunctionCallArgValueId>,
) -> Llm
pub fn with_function_call_arg_value( &self, value: impl IntoID<FunctionCallArgValueId>, ) -> Llm
Set a variable of type FunctionCallArgValue in the llm environment
Arguments
value- The FunctionCallArgValue value to assign to the variable
Sourcepub fn with_generated_code(&self, value: impl IntoID<GeneratedCodeId>) -> Llm
pub fn with_generated_code(&self, value: impl IntoID<GeneratedCodeId>) -> Llm
Set a variable of type GeneratedCode in the llm environment
Arguments
value- The GeneratedCode value to assign to the variable
Sourcepub fn with_git_ref(&self, value: impl IntoID<GitRefId>) -> Llm
pub fn with_git_ref(&self, value: impl IntoID<GitRefId>) -> Llm
Set a variable of type GitRef in the llm environment
Arguments
value- The GitRef value to assign to the variable
Sourcepub fn with_git_repository(&self, value: impl IntoID<GitRepositoryId>) -> Llm
pub fn with_git_repository(&self, value: impl IntoID<GitRepositoryId>) -> Llm
Set a variable of type GitRepository in the llm environment
Arguments
value- The GitRepository value to assign to the variable
Sourcepub fn with_input_type_def(&self, value: impl IntoID<InputTypeDefId>) -> Llm
pub fn with_input_type_def(&self, value: impl IntoID<InputTypeDefId>) -> Llm
Set a variable of type InputTypeDef in the llm environment
Arguments
value- The InputTypeDef value to assign to the variable
Sourcepub fn with_interface_type_def(
&self,
value: impl IntoID<InterfaceTypeDefId>,
) -> Llm
pub fn with_interface_type_def( &self, value: impl IntoID<InterfaceTypeDefId>, ) -> Llm
Set a variable of type InterfaceTypeDef in the llm environment
Arguments
value- The InterfaceTypeDef value to assign to the variable
Sourcepub fn with_llm(&self, value: impl IntoID<Llmid>) -> Llm
pub fn with_llm(&self, value: impl IntoID<Llmid>) -> Llm
Set a variable of type LLM in the llm environment
Arguments
value- The LLM value to assign to the variable
Sourcepub fn with_list_type_def(&self, value: impl IntoID<ListTypeDefId>) -> Llm
pub fn with_list_type_def(&self, value: impl IntoID<ListTypeDefId>) -> Llm
Set a variable of type ListTypeDef in the llm environment
Arguments
value- The ListTypeDef value to assign to the variable
Sourcepub fn with_model(&self, model: impl Into<String>) -> Llm
pub fn with_model(&self, model: impl Into<String>) -> Llm
Sourcepub fn with_module(&self, value: impl IntoID<ModuleId>) -> Llm
pub fn with_module(&self, value: impl IntoID<ModuleId>) -> Llm
Set a variable of type Module in the llm environment
Arguments
value- The Module value to assign to the variable
Sourcepub fn with_module_config_client(
&self,
value: impl IntoID<ModuleConfigClientId>,
) -> Llm
pub fn with_module_config_client( &self, value: impl IntoID<ModuleConfigClientId>, ) -> Llm
Set a variable of type ModuleConfigClient in the llm environment
Arguments
value- The ModuleConfigClient value to assign to the variable
Sourcepub fn with_module_source(&self, value: impl IntoID<ModuleSourceId>) -> Llm
pub fn with_module_source(&self, value: impl IntoID<ModuleSourceId>) -> Llm
Set a variable of type ModuleSource in the llm environment
Arguments
value- The ModuleSource value to assign to the variable
Sourcepub fn with_object_type_def(&self, value: impl IntoID<ObjectTypeDefId>) -> Llm
pub fn with_object_type_def(&self, value: impl IntoID<ObjectTypeDefId>) -> Llm
Set a variable of type ObjectTypeDef in the llm environment
Arguments
value- The ObjectTypeDef value to assign to the variable
Sourcepub fn with_prompt(&self, prompt: impl Into<String>) -> Llm
pub fn with_prompt(&self, prompt: impl Into<String>) -> Llm
Sourcepub fn with_prompt_file(&self, file: impl IntoID<FileId>) -> Llm
pub fn with_prompt_file(&self, file: impl IntoID<FileId>) -> Llm
Sourcepub fn with_prompt_var(
&self,
name: impl Into<String>,
value: impl Into<String>,
) -> Llm
pub fn with_prompt_var( &self, name: impl Into<String>, value: impl Into<String>, ) -> Llm
Add a string variable to the LLM’s environment
Arguments
name- The variable namevalue- The variable value
Sourcepub fn with_query(&self) -> Llm
pub fn with_query(&self) -> Llm
Provide the entire Query object to the LLM
Sourcepub fn with_sdk_config(&self, value: impl IntoID<SdkConfigId>) -> Llm
pub fn with_sdk_config(&self, value: impl IntoID<SdkConfigId>) -> Llm
Set a variable of type SDKConfig in the llm environment
Arguments
value- The SDKConfig value to assign to the variable
Sourcepub fn with_scalar_type_def(&self, value: impl IntoID<ScalarTypeDefId>) -> Llm
pub fn with_scalar_type_def(&self, value: impl IntoID<ScalarTypeDefId>) -> Llm
Set a variable of type ScalarTypeDef in the llm environment
Arguments
value- The ScalarTypeDef value to assign to the variable
Sourcepub fn with_secret(&self, value: impl IntoID<SecretId>) -> Llm
pub fn with_secret(&self, value: impl IntoID<SecretId>) -> Llm
Set a variable of type Secret in the llm environment
Arguments
value- The Secret value to assign to the variable
Sourcepub fn with_service(&self, value: impl IntoID<ServiceId>) -> Llm
pub fn with_service(&self, value: impl IntoID<ServiceId>) -> Llm
Set a variable of type Service in the llm environment
Arguments
value- The Service value to assign to the variable
Sourcepub fn with_socket(&self, value: impl IntoID<SocketId>) -> Llm
pub fn with_socket(&self, value: impl IntoID<SocketId>) -> Llm
Set a variable of type Socket in the llm environment
Arguments
value- The Socket value to assign to the variable
Sourcepub fn with_source_map(&self, value: impl IntoID<SourceMapId>) -> Llm
pub fn with_source_map(&self, value: impl IntoID<SourceMapId>) -> Llm
Set a variable of type SourceMap in the llm environment
Arguments
value- The SourceMap value to assign to the variable
Sourcepub fn with_terminal(&self, value: impl IntoID<TerminalId>) -> Llm
pub fn with_terminal(&self, value: impl IntoID<TerminalId>) -> Llm
Set a variable of type Terminal in the llm environment
Arguments
value- The Terminal value to assign to the variable