pub struct LlmMessage {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
Sourceimpl LlmMessage
impl LlmMessage
Sourcepub async fn content(&self) -> Result<Vec<LlmContentBlock>, DaggerError>
pub async fn content(&self) -> Result<Vec<LlmContentBlock>, DaggerError>
The message’s content blocks, in the order the model produced them.
Sourcepub async fn id(&self) -> Result<Id, DaggerError>
pub async fn id(&self) -> Result<Id, DaggerError>
A unique identifier for this LLMMessage.
Sourcepub async fn role(&self) -> Result<LlmMessageRole, DaggerError>
pub async fn role(&self) -> Result<LlmMessageRole, DaggerError>
The role that produced this message.
Sourcepub fn token_usage(&self) -> LlmTokenUsage
pub fn token_usage(&self) -> LlmTokenUsage
Token usage reported by the provider for the API call that produced this message; all zeros except on assistant responses.