Struct dagger_sdk::ObjectTypeDef
source · pub struct ObjectTypeDef {
pub proc: Option<Arc<DaggerSessionProc>>,
pub selection: Selection,
pub graphql_client: DynGraphQLClient,
}Fields
proc: Option<Arc<DaggerSessionProc>>selection: Selectiongraphql_client: DynGraphQLClientImplementations
sourceimpl ObjectTypeDef
impl ObjectTypeDef
sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The function used to construct new instances of this object, if any
sourcepub async fn description(&self) -> Result<String, DaggerError>
pub async fn description(&self) -> Result<String, DaggerError>
The doc string for the object, if any.
sourcepub fn fields(&self) -> Vec<FieldTypeDef>
pub fn fields(&self) -> Vec<FieldTypeDef>
Static fields defined on this object, if any.
sourcepub async fn id(&self) -> Result<ObjectTypeDefId, DaggerError>
pub async fn id(&self) -> Result<ObjectTypeDefId, DaggerError>
A unique identifier for this ObjectTypeDef.
sourcepub async fn name(&self) -> Result<String, DaggerError>
pub async fn name(&self) -> Result<String, DaggerError>
The name of the object.
sourcepub async fn source_module_name(&self) -> Result<String, DaggerError>
pub async fn source_module_name(&self) -> Result<String, DaggerError>
If this ObjectTypeDef is associated with a Module, the name of the module. Unset otherwise.