Struct dagger_sdk::Query

source ·
pub struct Query {
    pub proc: Arc<Child>,
    pub selection: Selection,
    pub conn: ConnectParams,
}

Fields

proc: Arc<Child>selection: Selectionconn: ConnectParams

Implementations

source

impl Query

source

pub fn cache_volume(&self, key: impl Into<String>) -> CacheVolume

Constructs a cache volume for a given cache key.

Arguments
  • key - A string identifier to target this cache volume (e.g. “myapp-cache”).
source

pub fn container(&self) -> Container

Loads a container from ID. Null ID returns an empty container (scratch). Optional platform argument initializes new containers to execute and publish as that platform. Platform defaults to that of the builder’s host.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
source

pub fn container_opts(&self, opts: QueryContainerOpts) -> Container

Loads a container from ID. Null ID returns an empty container (scratch). Optional platform argument initializes new containers to execute and publish as that platform. Platform defaults to that of the builder’s host.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
source

pub async fn default_platform(&self) -> Result<Platform>

The default platform of the builder.

source

pub fn directory(&self) -> Directory

Load a directory by ID. No argument produces an empty directory.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
source

pub fn directory_opts(&self, opts: QueryDirectoryOpts) -> Directory

Load a directory by ID. No argument produces an empty directory.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
source

pub fn file(&self, id: FileId) -> File

Loads a file by ID.

source

pub fn git(&self, url: impl Into<String>) -> GitRepository

Queries a git repository.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
source

pub fn git_opts( &self, url: impl Into<String>, opts: QueryGitOpts ) -> GitRepository

Queries a git repository.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
source

pub fn host(&self) -> Host

Queries the host environment.

source

pub fn http(&self, url: impl Into<String>) -> File

Returns a file containing an http remote url content.

source

pub fn pipeline(&self, name: impl Into<String>) -> Query

Creates a named sub-pipeline

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
source

pub fn pipeline_opts<'a>( &self, name: impl Into<String>, opts: QueryPipelineOpts<'a> ) -> Query

Creates a named sub-pipeline

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
source

pub fn project(&self, name: impl Into<String>) -> Project

Look up a project by name

source

pub fn secret(&self, id: SecretId) -> Secret

Loads a secret from its ID.

source

pub fn socket(&self) -> Socket

Loads a socket by its ID.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use
source

pub fn socket_opts(&self, opts: QuerySocketOpts) -> Socket

Loads a socket by its ID.

Arguments
  • opt - optional argument, see inner type for documentation, use _opts to use