pub struct QueryModuleSourceOpts<'a> {
pub ref_pin: Option<&'a str>,
pub rel_host_path: Option<&'a str>,
pub stable: Option<bool>,
}Fields
ref_pin: Option<&'a str>The pinned version of the module source
rel_host_path: Option<&'a str>The relative path to the module root from the host directory
stable: Option<bool>If true, enforce that the source is a stable version for source kinds that support versioning.