pub struct WorkspaceWithInitModuleOptsBuilder<'a> { /* private fields */ }Expand description
Builder for WorkspaceWithInitModuleOpts.
Implementations
Sourceimpl<'a> WorkspaceWithInitModuleOptsBuilder<'a>
impl<'a> WorkspaceWithInitModuleOptsBuilder<'a>
Sourcepub fn entrypoint<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn entrypoint<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Select this module as the entrypoint and install it. False prevents automatic selection. When omitted, select only if both path and name are omitted and the module is installed.
Sourcepub fn install<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn install<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Install the module. When omitted, install only if path is omitted.
Sourcepub fn name<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
Module name. The engine infers it from path, the active config file, or the workspace root when omitted.
Sourcepub fn path<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
pub fn path<VALUE: Into<&'a str>>(&mut self, value: VALUE) -> &mut Self
Module path relative to the workspace cwd, or an absolute workspace path. Defaults to .dagger/modules/
Sourcepub fn settings<VALUE: Into<Json>>(&mut self, value: VALUE) -> &mut Self
pub fn settings<VALUE: Into<Json>>(&mut self, value: VALUE) -> &mut Self
Explicit SDK-module constructor setting overrides for this scope.
Sourcepub fn build(
&self,
) -> Result<WorkspaceWithInitModuleOpts<'a>, WorkspaceWithInitModuleOptsBuilderError>
pub fn build( &self, ) -> Result<WorkspaceWithInitModuleOpts<'a>, WorkspaceWithInitModuleOptsBuilderError>